# French language file.
#
# Epona (c) 2000 PegSoft
# Contact us at epona@pegirc.com
#
# This program is free but copyrighted software; see the file COPYING for
# details.
#
# Based on the original code of Services by Andy Church.
#
# When translating this file to another language, keep in mind that the
# order of parameters for sprintf() is fixed in the source code, so your
# messages need to take the same parameters in the same order as the
# English messages do.  (Obviously, this doesn't hold for the strftime()
# format lines immediately below.)  If you can't get a natural translation
# of a message without changing the order of the parameters, let me know
# (achurch@dragonfire.net) which message is causing a problem and I'll see
# what I can do.
#
# In help messages, "%S" (capital S, not lowercase) refers to the name of
# the service sending the message; for example, in NickServ help messages,
# "%S" is replaced by "NickServ" (or whatever it is renamed to in
# config.h).  The %S's do not count as sprintf() parameters, so they can be
# rearranged, removed, or added as necessary.
#
# Also in help messages, please try to limit line lengths to 60 characters
# of text (not including the leading tab).  This length was chosen because
# it does not cause line wrap under default settings on most current IRC
# clients.  Remember that format characters (control-B, control-_) are not
# included in that 60-character limit (since they don't show on the user's
# screen).  Also remember that format specifiers (%S, etc.) will expand
# when displayed, so remember to take this into account; you can assume
# that the length of a pseudoclient name (%S replacement) will be eight
# characters, so reduce the maximum line length by 6 for every %S on a
# line.
#
# Finally, remember to put a tab at the beginning of every line of text
# (including empty lines).  This has to be a tab, not spaces.

###########################################################################
#
# Name of this language
#
###########################################################################

# For languages other than English, this string should have the following
# format:
#     language-name-in-language (language-name-in-English)
# For example, "Espaol (Spanish)" or "Franais (French)".

LANG_NAME
	Franais (French)

###########################################################################
#
# General messages
#
###########################################################################

# strftime() format strings.  man 3 strftime for information on the
# meanings of the format specifiers.  Short version:
#	%a = weekday name (short)	%H = hour
#	%b = month name (short)		%M = minute
#	%d = day of month		%S = second
#	%Y = year			%Z = time zone

# This is used as the format string for strftime() for a date and time
# together.
STRFTIME_DATE_TIME_FORMAT
	%d %b %Y %H:%M:%S %Z
# This is used as the format string for strftime() for a date alone in long
# format (English: including weekday).
STRFTIME_LONG_DATE_FORMAT
	%a %d %b %Y
# This is used as the format string for strftime() for a date alone in
# short format (English: without weekday).
STRFTIME_SHORT_DATE_FORMAT
	%d %b %Y

# These tell our strftime() what the names of months and days are.  If you
# don't use %a, %A, %b, or %B in your strftime() strings above, you can
# leave these empty.  However, if you enter names, they MUST stay in order,
# one per line, and the list MUST be complete!

# %a
STRFTIME_DAYS_SHORT
	Dim
	Lun
	Mar
	Mer
	Jeu
	Ven
	Sam
# %A
STRFTIME_DAYS_LONG
	Dimanche
	Lundi
	Mardi
	Mercredi
	Jeudi
	Vendredi
	Samedi
# %b
STRFTIME_MONTHS_SHORT
	Jan
	Fev
	Mar
	Avr
	Mai
	Jun
	Jul
	Aou
	Sep
	Oct
	Nov
	Dec
# %B
STRFTIME_MONTHS_LONG
	Janvier
	Fvrier
	Mars
	Avril
	Mai
	Juin
	Juillet
	Aot
	Septembre
	Octobre
	Novembre
	Dcembre


# This is used in ChanServ/NickServ INFO displays.
COMMA_SPACE
	, 


# Various error messages.
USER_RECORD_NOT_FOUND
	Erreur interne - impossible d'effectuer la commande.
UNKNOWN_COMMAND
	Commande %s inconnue.
UNKNOWN_COMMAND_HELP
	Commande %s inconnue. Tapez "/msg %s HELP" pour obtenir de l'aide.
SYNTAX_ERROR
	Syntaxe: %s
MORE_INFO
	Tapez /msg %s HELP %s pour plus d'informations.
NO_HELP_AVAILABLE
	Aucune aide disponible sur %s.

BAD_USERHOST_MASK
	Le masque doit avoir le format user@host.
BAD_EXPIRY_TIME
	Echance invalide.

SERVICE_OFFLINE
	%s n'est pas connect actuellement.
READ_ONLY_MODE
	Note: les Services sont en mode lecture-seule; les changements ne seront pas sauvegards!
PASSWORD_INCORRECT
	Mot de passe incorrect.

# What's the difference between "Access denied" and "Permission denied"?
# Very little; you can safely make them the same message with no real loss
# of meaning.  If you want to make a distinction, "Access denied" is
# usually used more generally; for example, a non-oper trying to access
# OperServ gets "Access denied", while a non-Services admin trying to use
# NickServ SET NOEXPIRE gets "Permission denied".
ACCESS_DENIED
	Accs refus.
PERMISSION_DENIED
	Permission refuse.

MORE_OBSCURE_PASSWORD
	Veuillez ressayer avec un mot de passe plus difficile  trouver.  Les mots de passe doivent contenir au moins cinq caractres, ne doivent pas tre trop facilement devinables (par exemple votre vrai nom ou votre nick), et ne doit pas contenir d'espaces ou de tabulations.
PASSWORD_TRUNCATED
	Note:  Votre mot de passe a t tronqu  %d caractres.

NICK_NOT_REGISTERED
	Votre nick n'est pas enregistr.
NICK_NOT_REGISTERED_HELP
	Votre nick n'est pas enregistr.  Tapez /msg %s HELP pour des informations sur l'enregistrement des nicks.
NICK_X_NOT_REGISTERED
	Le nick %s n'est pas enregistr.
NICK_X_NOT_IN_USE
	Le nick %s n'est actuellement pas utilis.
NICK_X_FORBIDDEN
	Le nick %s ne peut tre enregistr ou utilis.
NICK_X_FORBIDDEN_OPER
	Le nick %s a t interdit par %s:
	%s
CHAN_X_NOT_REGISTERED
	Le channel %s n'est pas enregistr.
CHAN_X_NOT_IN_USE
	Le channel %s n'existe pas.
CHAN_X_FORBIDDEN
	Le channel %s ne peut tre enregistr ou utilis.
CHAN_X_FORBIDDEN_OPER
	Le channel %s a t interdit par %s:
	%s
NICK_IDENTIFY_REQUIRED
	L'authentification par mot de passe est requise pour cette commande.
	Ressayez aprs avoir tap /msg %s IDENTIFY motdepasse.
CHAN_IDENTIFY_REQUIRED
	L'authentification par mot de passe est requise pour cette commande.
	Ressayez aprs avoir tap /msg %s IDENTIFY %s motdepasse.
	
MAIL_DISABLED
	Les services ont t configurs pour ne pas envoyer de mail.
MAIL_INVALID
	L'adresse e-mail de %s est invalide.
MAIL_LATER
	Impossible d'envoyer un e-mail maintenant; ressayez un peu
	plus tard.
MAIL_DELAYED
	Attendez %d secondes et ressayez.
	
NO_REASON
	Aucune raison
UNKNOWN
	<inconnu>

###########################################################################
#
# NickServ messages
#
###########################################################################

# Automatic messages
NICK_IS_REGISTERED
	Ce nick appartient  quelqu'un d'autre. Veuillez en changer.
	(Si c'est votre nick, tapez /msg %s IDENTIFY motdepasse.)
NICK_IS_SECURE
	Ce nick est enregistr et protg. Si c'est votre nick,
	tapez /msg %s IDENTIFY motdepasse. 
	Sinon, veuillez choisir un nick diffrent.
NICK_MAY_NOT_BE_USED
	Ce nick ne peut tre utilis.  Veuillez en choisir un autre.
FORCENICKCHANGE_IN_1_MINUTE
	Si vous ne changez pas d'ici 1 minute, je changerai votre nick.
FORCENICKCHANGE_IN_20_SECONDS
	Si vous ne changez pas d'ici 20 secondes, je changerai votre nick.
FORCENICKCHANGE_NOW
	Ce nick a t enregistr; vous ne pouvez pas l'utiliser.
	Votre nick est maintenant chang en %s.

# REGISTER responses
NICK_REGISTER_SYNTAX
	REGISTER motdepasse [email]
NICK_REGISTER_SYNTAX_EMAIL
	REGISTER motdepasse email
NICK_REGISTRATION_DISABLED
	Dsols, l'enregistrement de nicks est temporairement dsactiv.
NICK_REGISTRATION_FAILED
	Dsols, l'enregistrement a chou.
NICK_REG_PLEASE_WAIT
	Veuillez attendre %d secondes avant d'utiliser la commande REGISTER  nouveau.
NICK_CANNOT_BE_REGISTERED
	Le nick %s ne peut tre enregistr.
NICK_ALREADY_REGISTERED
	Le nick %s est dj enregistr!
NICK_REGISTERED
	Le nick %s est maintenant enregistr sous votre masque: %s
NICK_PASSWORD_IS
	Votre mot de passe est %s - notez le pour une utilisation ultrieure.

# IDENTIFY responses
NICK_IDENTIFY_SYNTAX
	IDENTIFY motdepasse
NICK_IDENTIFY_FAILED
	Dsols, l'identification a chou.
NICK_IDENTIFY_SUCCEEDED
	Mot de passe accept - vous tes maintenant identifi.
NICK_IDENTIFY_EMAIL_REQUIRED
	Vous devez maintenant associer un e-mail  votre nick.
	Cet e-mail permettra aux administrateurs du rseau de
	vous envoyer votre mot de passe si vous le perdez.
	Tapez /msg %S SET EMAIL e-mail pour le dfinir.
	Ce message apparaitra tant que votre nick n'a pas 
	d'e-mail associ.

# DROP responses
NICK_DROP_SYNTAX
	DROP
NICK_DROP_DISABLED
	Dsols, l'effacement de nick est temporairement dsactiv.
NICK_DROPPED
	Votre nick a t effac.
NICK_X_DROPPED
	Le nick %s a t effac.

# SET responses
NICK_SET_SYNTAX
	SET option paramtres
NICK_SET_SERVADMIN_SYNTAX
	SET [nick] option paramtres
NICK_SET_DISABLED
	Dsols, la configuration des options du nick est temporairement dsactive.
NICK_SET_UNKNOWN_OPTION
	L'option SET %s est inconnue.
NICK_SET_UNKNOWN_OPTION_OR_BAD_NICK
	L'option SET %s est inconnue, ou le nick n'est pas enregistr.

# SET PASSWORD responses
NICK_SET_PASSWORD_FAILED
	Impossible de changer votre mot de passe.
NICK_SET_PASSWORD_CHANGED
	Votre mot de passe a t chang.
NICK_SET_PASSWORD_CHANGED_TO
	Votre mot de passe est maintenant %s.

# SET LANGUAGE responses
NICK_SET_LANGUAGE_SYNTAX
	SET LANGUAGE nombre
NICK_SET_LANGUAGE_UNKNOWN
	Numro de langue %d inconnu. Tapez /msg %s HELP SET LANGUAGE pour une liste de langues.
NICK_SET_LANGUAGE_CHANGED
	Votre langue est maintenant le Franais.

# SET URL responses
NICK_SET_URL_CHANGED
	L'adresse de votre site est maintenant %s.
NICK_SET_URL_UNSET
	L'adresse de votre site a t efface.

# SET EMAIL responses
NICK_SET_EMAIL_CHANGED
	Votre adresse e-mail est maintenant %s.
NICK_SET_EMAIL_UNSET
	Votre adresse e-mail a t efface.
NICK_SET_EMAIL_UNSET_IMPOSSIBLE
	Vous ne pouvez pas effacer votre e-mail sur ce rseau.
	
# SET GREET responses
NICK_SET_GREET_CHANGED
	Votre message d'accueil est maintenant %s.
NICK_SET_GREET_UNSET
	Votre message d'accueil a t effac.

# SET KILL responses
NICK_SET_KILL_SYNTAX
	SET KILL {ON | QUICK | OFF}
NICK_SET_KILL_IMMED_SYNTAX
	SET KILL {ON | QUICK | IMMED | OFF}
NICK_SET_KILL_ON
	La protection est maintenant active.
NICK_SET_KILL_QUICK
	La protection est maintenant active, avec un dlai rduit.
NICK_SET_KILL_IMMED
	La protection est maintenant active, sans dlai.
NICK_SET_KILL_IMMED_DISABLED
	L'option IMMED n'est pas disponible sur ce rseau.
NICK_SET_KILL_OFF
	La protection est maintenant dsactive.

# SET SECURE responses
NICK_SET_SECURE_SYNTAX
	SET SECURE {ON | OFF}
NICK_SET_SECURE_ON
	La scurit est maintenant activ.
NICK_SET_SECURE_OFF
	La scurit est maintenant dsactiv.

# SET PRIVATE responses
NICK_SET_PRIVATE_SYNTAX
	SET PRIVATE {ON | OFF}
NICK_SET_PRIVATE_ON
	Votre nick est maintenant priv.
NICK_SET_PRIVATE_OFF
	Votre nick est maintenant public.

# SET HIDE responses
NICK_SET_HIDE_SYNTAX
	SET HIDE {EMAIL | USERMASK | QUIT} {ON | OFF}
NICK_SET_HIDE_EMAIL_ON
	Votre adresse e-mail ne sera plus affiche par la commande INFO de %s.
NICK_SET_HIDE_EMAIL_OFF
	Votre adresse e-mail sera affiche par la commande INFO de %s.
NICK_SET_HIDE_MASK_ON
	Votre masque user@host ne sera plus affich par la commande INFO de %s.
NICK_SET_HIDE_MASK_OFF
	Votre masque user@host sera affich par la commande INFO de %s.
NICK_SET_HIDE_QUIT_ON
	Votre dernire raison de /QUIT ne sera plus affiche par la commande INFO de %s.
NICK_SET_HIDE_QUIT_OFF
	Votre dernire raison de /QUIT sera affiche par la commande INFO de %s.

# SET NOEXPIRE responses
NICK_SET_NOEXPIRE_SYNTAX
	SET [nick] NOEXPIRE {ON | OFF}
NICK_SET_NOEXPIRE_ON
	Le nick %s n'expirera pas.
NICK_SET_NOEXPIRE_OFF
	Le nick %s expirera.

# ACCESS responses
NICK_ACCESS_SYNTAX
	ACCESS {ADD | DEL | LIST} [mask]
NICK_ACCESS_ALREADY_PRESENT
	Le mask %s existe dj sur votre liste d'accs.
NICK_ACCESS_REACHED_LIMIT
	Vous ne pouvez avoir que %d entres dans la liste d'accs d'un nick.
NICK_ACCESS_ADDED
	%s ajout  votre liste d'accs.
NICK_ACCESS_NOT_FOUND
	%s introuvable sur votre liste d'accs.
NICK_ACCESS_DELETED
	%s supprim de votre liste d'accs.
NICK_ACCESS_LIST
	Liste d'accs:
NICK_ACCESS_LIST_X
	Liste d'accs de %s:

# LINK responses
NICK_LINK_SYNTAX
	LINK nick motdepasse
NICK_LINK_DISABLED
	La commande LINK n'est pas disponible.
NICK_LINK_FAILED
	Dsols, la liaison a chou.
NICK_NO_LINK_SAME
	Vous ne pouvez relier un nick  lui-mme!
NICK_LINK_CIRCULAR
	Impossible de se relier  %s: liaison circulaire dtecte.
NICK_LINKED
	Votre nick a t reli  %s.

# UNLINK responses
NICK_UNLINK_SYNTAX
	UNLINK [nick motdepasse]
NICK_UNLINK_FAILED
	Dsols, la liaison n'a pu tre supprime.
NICK_NOT_LINKED
	Votre nick n'est pas reli.
NICK_UNLINKED
	La liaison  %s a t supprime.
NICK_X_NOT_LINKED
	Le nick %s n'est pas reli.
NICK_X_UNLINKED
	Le nick %s n'est plus reli  %s.
	
# LISTLINKS responses
NICK_LISTLINKS_SYNTAX
	LISTLINKS nick [ALL]
NICK_LISTLINKS_HEADER
	Liste des nicks relis  %s:
NICK_LISTLINKS_FOOTER
	%d nicks relis.

# INFO responses
NICK_INFO_SYNTAX
	INFO nick [ALL]
NICK_INFO_REALNAME
	%s est %s
NICK_INFO_ADDRESS
	            Adresse: %s
NICK_INFO_ADDRESS_ONLINE
	        Connect de: %s
NICK_INFO_ADDRESS_ONLINE_NOHOST
	%s est actuellement connect.
NICK_INFO_TIME_REGGED
	      Enregistr le: %s
NICK_INFO_LAST_SEEN
	  Dernire prsence: %s
NICK_INFO_LAST_QUIT
	       Dernier quit: %s
NICK_INFO_URL
	Adresse de son site: %s
NICK_INFO_EMAIL
	     Adresse e-mail: %s
NICK_INFO_GREET
	  Message d'accueil: %s
NICK_INFO_OPTIONS
	            Options: %s
# These strings MUST NOT be empty
NICK_INFO_OPT_KILL
	Protection
NICK_INFO_OPT_SECURE
	Securit
NICK_INFO_OPT_PRIVATE
	Priv
NICK_INFO_OPT_NONE
	Aucune
NICK_INFO_LINKED_TO
	            Reli : %s
NICK_INFO_NO_EXPIRE
	Ce nick n'expirera pas.
NICK_INFO_FOR_MORE
	Pour plus d'informations, tapez /msg %s INFO %s ALL.

# LIST responses
NICK_LIST_SYNTAX
	LIST modle
NICK_LIST_SERVADMIN_SYNTAX
	LIST modle [FORBIDDEN] [NOEXPIRE]
NICK_LIST_HEADER
	Liste des entres correspondantes  %s:
NICK_LIST_RESULTS
	Fin de la liste - %d/%d correspondances affiches.

# RECOVER responses
NICK_RECOVER_SYNTAX
	RECOVER nick [motdepasse]
NICK_NO_RECOVER_SELF
	Vous ne pouvez utiliser RECOVER sur vous-mme!
NICK_RECOVERED
	L'utilisateur se servant de votre nick a t dconnect.
	/msg %s RELEASE %s pour le rcuprer avant que la minute ne s'coule.

# RELEASE responses
NICK_RELEASE_SYNTAX
	RELEASE nick [motdepasse]
NICK_RELEASE_NOT_HELD
	Le nick %s n'est pas en tutelle.
NICK_RELEASED
	La tutelle des Services sur votre nick a t enleve.

# GHOST responses
NICK_GHOST_SYNTAX
	GHOST nick [motdepasse]
NICK_NO_GHOST_SELF
	Vous ne pouvez utiliser GHOST sur vous-mme!
NICK_GHOST_KILLED
	L'utilisateur fantme utilisant votre nick a t dconnect.

# GETPASS responses
NICK_GETPASS_SYNTAX
	GETPASS nick
NICK_GETPASS_UNAVAILABLE
	La commande GETPASS est indisponible car l'encryption est utilise.
NICK_GETPASS_PASSWORD_IS
	Le mot de passe de %s est %s.
	
# SENDPASS responses
NICK_SENDPASS_SYNTAX
	SENDPASS nickname
NICK_SENDPASS_UNAVAILABLE
	La commande SENDPASS est indisponible car l'encryption est utilise.
NICK_SENDPASS_SUBJECT
	Mot de passe du nick %s
NICK_SENDPASS_HEAD
	Bonjour,
NICK_SENDPASS_LINE_1
	Vous avez demand  recevoir le mot de passe du nick %s par e-mail.
NICK_SENDPASS_LINE_2
	Le mot de passe est %s. Pour des raisons de scurit, vous devriez le changer ds que vous lisez cet e-mail.
NICK_SENDPASS_LINE_3
	Si vous ne savez pas de quoi il retourne dans cet e-mail, il s'agit probablement d'une erreur; nous vous prions de nous excuser et vous demandons d'ignorer cet e-mail.
NICK_SENDPASS_LINE_4
	NE REPONDEZ PAS A CE MAIL!
NICK_SENDPASS_LINE_5
	Les administrateurs de %s.
NICK_SENDPASS_OK
	Le mot de passe de %s a t envoy.

# FORBID responses
NICK_FORBID_SYNTAX
	FORBID nick [raison]
NICK_FORBID_SYNTAX_REASON
	FORBID nick raison
NICK_FORBID_SUCCEEDED
	Le nick %s est dsormais interdit.
NICK_FORBID_FAILED
	Impossible d'interdire le nick %s!

###########################################################################
#
# ChanServ messages
#
###########################################################################

# Access level descriptions
CHAN_LEVEL_AUTOOP
	Status automatique d'oprateur du channel
CHAN_LEVEL_AUTOVOICE
	Mode +v automatique
CHAN_LEVEL_AUTOHALFOP
	Mode +h automatique
CHAN_LEVEL_AUTOPROTECT
	Mode +a automatique
CHAN_LEVEL_AUTODEOP
	Non autoris  avoir le status d'oprateur du channel
CHAN_LEVEL_NOJOIN
	Non autoris  joindre le channel s'il est restreint
CHAN_LEVEL_INVITE
	Autoris  utiliser la commande INVITE
CHAN_LEVEL_AKICK
	Autoris  utiliser la commande AKICK
CHAN_LEVEL_SET
	Autoris  utiliser la commande SET (mais pas FOUNDER/PASSWORD)
CHAN_LEVEL_CLEAR
	Autoris  utiliser la commande CLEAR
CHAN_LEVEL_UNBAN
	Autoris  utiliser la commande UNBAN
CHAN_LEVEL_OPDEOP
	Autoris  utiliser les commandes OP/DEOP
CHAN_LEVEL_ACCESS_LIST
	Autoris  voir la liste d'accs
CHAN_LEVEL_ACCESS_CHANGE
	Autoris  modifier la liste d'accs
CHAN_LEVEL_MEMO
	Autoris  lister/lire les memos
CHAN_LEVEL_ASSIGN
	Autoris  attribuer/retirer un bot
CHAN_LEVEL_BADWORDS
	Autoris  utiliser la commande BADWORDS
CHAN_LEVEL_NOKICK
	Jamais kick par les kickers du bot
CHAN_LEVEL_FANTASIA
	Autoris  utiliser les commandes fantaisistes
CHAN_LEVEL_SAY
	Autoris  utiliser les commandes ACT et SAY
CHAN_LEVEL_GREET
	Message d'accueil affich
CHAN_LEVEL_VOICEME
	Autoris  se (de)voicer
CHAN_LEVEL_VOICE
	Autoris  utiliser les commandes VOICE/DEVOICE
CHAN_LEVEL_GETKEY
	Autoris  utiliser la commande GETKEY
CHAN_LEVEL_OPDEOPME
	Autoris  se (de)op
CHAN_LEVEL_HALFOPME
	Autoris  se (de)halfop
CHAN_LEVEL_HALFOP
	Autoris  utiliser les commandes HALFOP/DEHALFOP
CHAN_LEVEL_PROTECTME
	Autoris  se (de)protger
CHAN_LEVEL_PROTECT
	Autoris  utiliser les commandes PROTECT/DEPROTECT

# Automatic responses
CHAN_IS_REGISTERED
	Ce channel a t enregistr avec %s.
CHAN_NOT_ALLOWED_OP
	Vous ne pouvez tre oprateur du channel %s.
CHAN_MAY_NOT_BE_USED
	Ce channel ne peut tre utilis.
CHAN_NOT_ALLOWED_TO_JOIN
	Vous n'tes pas autoris  tre sur ce channel.

# REGISTER responses
CHAN_REGISTER_SYNTAX
	REGISTER channel motdepasse description
CHAN_REGISTER_DISABLED
	Dsols, l'enregistrement de channels est temporairement dsactiv.
CHAN_REGISTER_NOT_LOCAL
	Les channels locaux ne peuvent tre enregistrs.
CHAN_MUST_REGISTER_NICK
	Vous devez d'abord enregistrer votre nick.  Tapez /msg %s HELP pour savoir comment enregistrer votre nick.
CHAN_MUST_IDENTIFY_NICK
	Vous devez d'abord vous identifier avec %s, en utilisant la commande:
	/msg %s IDENTIFY motdepasse
CHAN_MAY_NOT_BE_REGISTERED
	Le channel %s ne peut tre enregistr.
CHAN_ALREADY_REGISTERED
	Le channel %s est dj enregistr!
CHAN_MUST_BE_CHANOP
	Vous devez tre un oprateur du channel pour l'enregistrer.
CHAN_REACHED_CHANNEL_LIMIT
	Dsols, vous avez dj atteint votre limite de %d channels.
CHAN_EXCEEDED_CHANNEL_LIMIT
	Dsols, vous avez dj dpass votre limite de %d channels.
CHAN_REGISTRATION_FAILED
	Dsols, l'enregistrement a chou.
CHAN_REGISTERED
	Le channel %s a t enregistr sous votre nick: %s
CHAN_PASSWORD_IS
	Le mot de passe du channel est %s - notez le pour une utilisation ultrieure.

# IDENTIFY responses
CHAN_IDENTIFY_SYNTAX
	IDENTIFY channel motdepasse
CHAN_IDENTIFY_FAILED
	Dsols, l'identification a chou.
CHAN_IDENTIFY_SUCCEEDED
	Password accept - vous avez maintenant un level d'accs sur %s quivalent 
	 celui de son propritaire.

# DROP responses
CHAN_DROP_SYNTAX
	DROP channel
CHAN_DROP_DISABLED
	Dsols, l'effacement de channels est temporairement dsactiv.
CHAN_DROPPED
	Le channel %s a t effac.

# SET responses
CHAN_SET_SYNTAX
	SET channel option paramtres
CHAN_SET_DISABLED
	Dsols, la configuration des options du channel est temporairement dsactive.
CHAN_SET_UNKNOWN_OPTION
	Option SET %s inconnue.

# SET FOUNDER responses
CHAN_SET_FOUNDER_TOO_MANY_CHANS
	%s a trop de channels enregistrs.
CHAN_FOUNDER_CHANGED
	Le propritaire de %s est maintenant %s.

# SET SUCCESSOR responses
CHAN_SUCCESSOR_CHANGED
	Le successeur de %s est maintenant %s.
CHAN_SUCCESSOR_UNSET
	Il n'y a plus de successeur sur %s.

# SET PASSWORD responses
CHAN_SET_PASSWORD_FAILED
	Impossible de changer le mot de passe.
CHAN_PASSWORD_CHANGED
	Le mot de passe de %s a t chang.
CHAN_PASSWORD_CHANGED_TO
	Le mot de passe de %s est maintenant %s.

# SET DESC responses
CHAN_DESC_CHANGED
	La description de %s est maintenant %s.

# SET URL responses
CHAN_URL_CHANGED
	L'adresse du site de %s est maintenant %s.
CHAN_URL_UNSET
	L'adresse du site de %s a t efface.

# SET EMAIL responses
CHAN_EMAIL_CHANGED
	L'e-mail de %s est maintenant %s.
CHAN_EMAIL_UNSET
	L'e-mail de %s a t effac.

# SET ENTRYMSG responses
CHAN_ENTRY_MSG_CHANGED
	Le message d'entre de %s a t chang.
CHAN_ENTRY_MSG_UNSET
	Le message d'entre de %s a t effac.

# SET TOPIC responses
CHAN_SET_TOPIC_FAILED
	Impossible de changer le topic.
	
# SET BANTYPE responses
CHAN_SET_BANTYPE_INVALID
	%s n'est pas un type de ban valide.
CHAN_SET_BANTYPE_CHANGED
	Le type de ban du channel %s est maintenant le numro %d.

# SET MLOCK responses
CHAN_SET_MLOCK_KEY_REQUIRED
	Un paramtre est requis pour MLOCK +k.
CHAN_SET_MLOCK_LIMIT_REQUIRED
	Un paramtre est requis pour MLOCK +l.
CHAN_SET_MLOCK_FLOOD_REQUIRED
	Un paramtre est requis pour MLOCK +f.
CHAN_SET_MLOCK_REDIRECT_REQUIRED
	Un paramtre est requis pour MLOCK +L.
CHAN_SET_MLOCK_LIMIT_POSITIVE
	Le paramtre de MLOCK +l doit tre un nombre positif.
CHAN_SET_MLOCK_UNKNOWN_CHAR
	Mode %c inconnu et ignor.
CHAN_SET_MLOCK_L_REQUIRED
	Vous devez bloquer le mode +l pour pouvoir bloquer le mode +L.
CHAN_MLOCK_CHANGED
	Les modes bloqus sur le channel %s sont maintenant %s.
CHAN_MLOCK_REMOVED
	Il n'y a plus aucun mode bloqu sur %s.

# SET KEEPTOPIC responses
CHAN_SET_KEEPTOPIC_SYNTAX
	SET channel KEEPTOPIC {ON | OFF}
CHAN_SET_KEEPTOPIC_ON
	Le maintien du topic est maintenant activ.
CHAN_SET_KEEPTOPIC_OFF
	Le maintien du topic est maintenant dsactiv.

# SET TOPICLOCK responses
CHAN_SET_TOPICLOCK_SYNTAX
	SET channel TOPICLOCK {ON | OFF}
CHAN_SET_TOPICLOCK_ON
	Le verrouillage du topic est maintenant activ.
CHAN_SET_TOPICLOCK_OFF
	Le verrouillage du topic est maintenant dsactiv.

# SET PRIVATE responses
CHAN_SET_PRIVATE_SYNTAX
	SET channel PRIVATE {ON | OFF}
CHAN_SET_PRIVATE_ON
	Votre channel est maintenant priv.
CHAN_SET_PRIVATE_OFF
	Votre channel est maintenant public.

# SET SECUREOPS responses
CHAN_SET_SECUREOPS_SYNTAX
	SET channel SECUREOPS {ON | OFF}
CHAN_SET_SECUREOPS_ON
	Le contrle des ops est maintenant activ.
CHAN_SET_SECUREOPS_OFF
	Le contrle des ops est maintenant dsactiv.
	
# SET SECUREFOUNDER responses
CHAN_SET_SECUREFOUNDER_SYNTAX
	SET channel SECUREFOUNDER {ON | OFF}
CHAN_SET_SECUREFOUNDER_ON
	Le contrle du propritaire est maintenant activ.
CHAN_SET_SECUREFOUNDER_OFF
	Le contrle du propritaire est maintenant dsactiv.

# SET LEAVEOPS responses
CHAN_SET_LEAVEOPS_SYNTAX
	SET channel LEAVEOPS {ON | OFF}
CHAN_SET_LEAVEOPS_ON
	Le deop strict est maintenant activ.
CHAN_SET_LEAVEOPS_OFF
	Le deop strict est maintenant dsactiv.

# SET RESTRICTED responses
CHAN_SET_RESTRICTED_SYNTAX
	SET channel RESTRICTED {ON | OFF}
CHAN_SET_RESTRICTED_ON
	L'accs restreint est maintenant activ.
CHAN_SET_RESTRICTED_OFF
	L'accs restreint est maintenant dsactiv.

# SET SECURE responses
CHAN_SET_SECURE_SYNTAX
	SET channel SECURE {ON | OFF}
CHAN_SET_SECURE_ON
	La scurit est maintenant active.
CHAN_SET_SECURE_OFF
	La scurit est maintenant dsactive.

# SET OPNOTICE responses
CHAN_SET_OPNOTICE_SYNTAX
	SET channel OPNOTICE {ON | OFF}
CHAN_SET_OPNOTICE_ON
	La notice sur OP/DEOP est maintenant activ.
CHAN_SET_OPNOTICE_OFF
	La notice sur OP/DEOP est maintenant dsactiv.

# SET NOEXPIRE responses
CHAN_SET_NOEXPIRE_SYNTAX
	SET channel NOEXPIRE {ON | OFF}
CHAN_SET_NOEXPIRE_ON
	Le channel %s n'expirera pas.
CHAN_SET_NOEXPIRE_OFF
	Le channel %s expirera.

# ACCESS messages
CHAN_ACCESS_SYNTAX
	ACCESS channel {ADD|DEL|LIST|CLEAR} [nick [level] | liste-d'entres]
CHAN_ACCESS_DISABLED
	Dsols, la modification des listes d'accs des channels est temporairement dsactive.
CHAN_ACCESS_LEVEL_NONZERO
	Le level d'accs doit tre diffrent de zro.
CHAN_ACCESS_LEVEL_RANGE
	Le level d'accs doit tre compris entre %d et %d inclus.
CHAN_ACCESS_NICKS_ONLY
	Les listes d'accs des channels ne peuvent contenir que des nicks enregistrs.
CHAN_ACCESS_REACHED_LIMIT
	Dsols, vous ne pouvez avoir que %d entres sur la liste d'accs d'un channel.
CHAN_ACCESS_LEVEL_UNCHANGED
	Le level d'accs de %s sur %s est inchang.
CHAN_ACCESS_LEVEL_CHANGED
	Le level d'accs de %s sur %s est maintenant de %d.
CHAN_ACCESS_ADDED
	%s ajout  la liste d'accs de %s au level %d.
CHAN_ACCESS_NO_SUCH_ENTRY
	Entre inexistante (#%d) sur la liste d'accs de %s.
CHAN_ACCESS_NOT_FOUND
	%s introuvable sur la liste d'accs de %s.
CHAN_ACCESS_NO_MATCH
	Aucune entre correspondante sur la liste d'accs de %s.
CHAN_ACCESS_DELETED
	%s supprim de la liste d'accs de %s.
CHAN_ACCESS_DELETED_ONE
	1 entre supprime de la liste d'accs de %s.
CHAN_ACCESS_DELETED_SEVERAL
	%d entres supprimes de la liste d'accs de %s.
CHAN_ACCESS_LIST_EMPTY
	La liste d'accs de %s est vide.
CHAN_ACCESS_LIST_HEADER
	Liste d'accs de %s:
	  Num   Lev  Nick
CHAN_ACCESS_LIST_FORMAT
	  %3d  %4d  %s%s%s%s
CHAN_ACCESS_CLEAR
	La liste d'accs est maintenant vide.

# AOP/SOP error response
CHAN_NO_AOP_SOP
	Pour assigner des privilges aux utilisateurs du channel,
	utilisez la commande ACCESS; tapez /msg %s HELP ACCESS
	pour plus d'informations.

# AKICK responses
CHAN_AKICK_SYNTAX
	AKICK channel {ADD | DEL | LIST | VIEW | ENFORCE | CLEAR} [nick-ou-usermask]
CHAN_AKICK_DISABLED
	Dsols, la modification de la liste de kicks automatiques du channel 
	est temporairement dsactive.
CHAN_AKICK_ALREADY_EXISTS
	%s existe dj sur la liste de kicks automatiques de %s.
CHAN_AKICK_REACHED_LIMIT
	Dsols, vous ne pouvez avoir plus de %d entres de kicks automatiques 
	sur un channel.
CHAN_AKICK_ADDED
	%s ajout  la liste de kicks automatiques de %s.
CHAN_AKICK_NO_SUCH_ENTRY
	Entre (#%d) inexistante sur la liste de kicks automatiques de %s.
CHAN_AKICK_NOT_FOUND
	%s introuvable sur la liste de kicks automatiques de %s.
CHAN_AKICK_NO_MATCH
	Aucune entre correspondante sur la liste de kicks automatiques de %s.
CHAN_AKICK_DELETED
	%s supprim de la liste de kicks automatiques de %s.
CHAN_AKICK_DELETED_ONE
	1 entre supprime de la liste de kicks automatiques de %s.
CHAN_AKICK_DELETED_SEVERAL
	%d entres supprimes de la liste de kicks automatiques de %s.
CHAN_AKICK_LIST_EMPTY
	la liste de kicks automatiques de %s est vide.
CHAN_AKICK_LIST_HEADER
	Liste de kicks automatiques de %s:
CHAN_AKICK_LIST_FORMAT
	  %3d %s%s
CHAN_AKICK_VIEW_FORMAT
	%3d %s (par %s le %s)
	    %s
CHAN_AKICK_ENFORCE_DONE
	L'application des entres de la liste de kicks automatiques 
	pour %s est termin; %d utilisateurs taient concerns.
CHAN_AKICK_CLEAR
	La liste de kicks automatiques est maintenant vide.

# LEVELS responses
CHAN_LEVELS_SYNTAX
	LEVELS channel {SET | DIS[ABLE] | LIST | RESET} [option [level]]
CHAN_LEVELS_RANGE
	Le level doit tre compris entre %d et %d inclus.
CHAN_LEVELS_CHANGED
	Le level pour %s du channel %s est maintenant de %d.
CHAN_LEVELS_UNKNOWN
	L'option %s est inconnue.  Tapez /msg %s HELP LEVELS DESC pour une 
	liste d'options valides.
CHAN_LEVELS_DISABLED
	Le level %s est maintenant dsactiv sur le channel %s.
CHAN_LEVELS_LIST_HEADER
	Options de level d'accs du channel %s:
CHAN_LEVELS_LIST_DISABLED
	    %-*s  (dsactiv)
CHAN_LEVELS_LIST_FOUNDER
	    %-*s  (propritaire uniquement)
CHAN_LEVELS_LIST_NORMAL
	    %-*s  %d
CHAN_LEVELS_RESET
	Les levels d'accs de %s ont t rinitialiss  leur valeur par dfaut.

# INFO responses
CHAN_INFO_SYNTAX
	INFO channel [ALL]
CHAN_INFO_HEADER
	Informations pour le channel %s:
CHAN_INFO_FOUNDER
	        Propritaire: %s (%s)
CHAN_INFO_NO_FOUNDER
	        Propritaire: %s
CHAN_INFO_SUCCESSOR
	          Successeur: %s (%s)
CHAN_INFO_NO_SUCCESSOR
	          Successeur: %s
CHAN_INFO_DESCRIPTION
	         Description: %s
CHAN_INFO_ENTRYMSG
	    Message d'entre: %s
CHAN_INFO_TIME_REGGED
	          Enregistr: %s
CHAN_INFO_LAST_USED
	Dernire utilisation: %s
CHAN_INFO_LAST_TOPIC
	       Dernier topic: %s
CHAN_INFO_TOPIC_SET_BY
	    Topic chang par: %s
CHAN_INFO_URL
	     Adresse du site: %s
CHAN_INFO_EMAIL
	              E-mail: %s
CHAN_INFO_BANTYPE
	         Type de ban: %d
CHAN_INFO_OPTIONS
	             Options: %s
CHAN_INFO_MODE_LOCK
	       Modes bloqus: %s
CHAN_INFO_OPT_PRIVATE
	Priv
CHAN_INFO_OPT_KEEPTOPIC
	Maintien du topic
CHAN_INFO_OPT_TOPICLOCK
	Verrouillage du topic
CHAN_INFO_OPT_SECUREOPS
	Contrle des ops
CHAN_INFO_OPT_SECUREFOUNDER
	Contrle du propritaire
CHAN_INFO_OPT_LEAVEOPS
	Deop strict
CHAN_INFO_OPT_RESTRICTED
	Accs restreint
CHAN_INFO_OPT_SECURE
	Securit
CHAN_INFO_OPT_NONE
	Aucune
CHAN_INFO_NO_EXPIRE
	Ce channel n'expirera pas.

# LIST responses
CHAN_LIST_SYNTAX
	LIST modle
CHAN_LIST_SERVADMIN_SYNTAX
	LIST pattern [FORBIDDEN] [NOEXPIRE]
CHAN_LIST_HEADER
	Liste d'entres correspondantes  %s:
CHAN_LIST_FORMAT
	    %-20s  %s
CHAN_LIST_END
	Fin de la liste - %d/%d correspondances affiches.

# INVITE responses
CHAN_INVITE_SYNTAX
	INVITE channel

# UNBAN responses
CHAN_UNBAN_SYNTAX
	UNBAN channel
CHAN_UNBANNED
	Vous avez t dbanni de %s.

# CLEAR responses
CHAN_CLEAR_SYNTAX
	CLEAR channel quoi
CHAN_CLEARED_BANS
	Tous les bans du channel %s ont t supprims.
CHAN_CLEARED_MODES
	Tous les modes du channel %s ont t rinitialiss.
CHAN_CLEARED_OPS
	Tous les ops du channel %s ont t enlevs.
CHAN_CLEARED_VOICES
	Tous les voices du channel %s ont t enlevs.
CHAN_CLEARED_USERS
	Tous les utilisateurs du channel %s ont t kicks.

# GETPASS responses
CHAN_GETPASS_SYNTAX
	GETPASS channel
CHAN_GETPASS_UNAVAILABLE
	La commande GETPASS est indisponible car l'encryption est utilise.
CHAN_GETPASS_PASSWORD_IS
	Le mot de passe du channel %s est %s.
	
# SENDPASS responses
CHAN_SENDPASS_SYNTAX
	SENDPASS channel
CHAN_SENDPASS_UNAVAILABLE
	La commande SENDPASS est indisponible car l'encryption est utilise.
CHAN_SENDPASS_SUBJECT
	Mot de passe du channel %s
CHAN_SENDPASS_HEAD
	Bonjour,
CHAN_SENDPASS_LINE_1
	Vous avez demand  recevoir le mot de passe du channel %s par e-mail.
CHAN_SENDPASS_LINE_2
	Le mot de passe est %s. Pour des raisons de scurit, vous devriez le changer ds que vous lisez ce mail.
CHAN_SENDPASS_LINE_3
	Si vous ne savez pas de quoi il retourne dans cet e-mail, il s'agit probablement d'une erreur; nous vous prions de nous excuser et vous demandons d'ignorer cet e-mail.
CHAN_SENDPASS_LINE_4
	NE REPONDEZ PAS A CE MAIL!
CHAN_SENDPASS_LINE_5
	Les administrateurs de %s.
CHAN_SENDPASS_OK
	Le mot de passe de %s a t envoy.

# FORBID responses
CHAN_FORBID_SYNTAX
	FORBID channel [raison]
CHAN_FORBID_SYNTAX_REASON
	FORBID channel raison
CHAN_FORBID_SUCCEEDED
	Le channel %s est maintenant interdit.
CHAN_FORBID_FAILED
	Impossible d'interdire le channel %s!

###########################################################################
#
# MemoServ messages
#
###########################################################################

# Automatic messages
MEMO_HAVE_NEW_MEMO
	Vous avez 1 nouveau memo.
MEMO_HAVE_NEW_MEMOS
	Vous avez %d nouveaux memos.
MEMO_TYPE_READ_LAST
	Tapez /msg %s READ LAST pour le lire.
MEMO_TYPE_READ_NUM
	Tapez /msg %s READ %d pour le lire.
MEMO_TYPE_LIST_NEW
	Tapez /msg %s LIST NEW pour les lister.
MEMO_AT_LIMIT
	Attention: Vous avez atteint votre nombre maximum de memos (%d).  Vous ne pourrez plus recevoir de nouveaux memos sauf si vous supprimez quelques uns de vos memos actuels. 
MEMO_OVER_LIMIT
	Attention: Vous avez dpass votre nombre maximum de memos (%d).  Vous ne pourrez plus recevoir de nouveaux memos sauf si vous supprimez quelques uns de vos memos actuels. 

MEMO_NEW_MEMO_ARRIVED
	Vous avez un nouveau memo de %s.
	Tapez /msg %s READ %d pour le lire.

# Multi-use responses
MEMO_HAVE_NO_MEMOS
	Vous n'avez pas de memos.
MEMO_X_HAS_NO_MEMOS
	%s n'a pas de memos.
MEMO_DOES_NOT_EXIST
	Memo %d n'existe pas!
MEMO_LIST_NOT_FOUND
	Aucun memo correspondant trouv.

# SEND responses
MEMO_SEND_SYNTAX
	SEND {nick | channel} texte-du-memo
MEMO_SEND_DISABLED
	Dsols, l'envoi de memos est temporairement dsactiv.
MEMO_SEND_PLEASE_WAIT
	Veuillez patienter %d secondes avant d'utiliser la commande SEND  nouveau.
MEMO_X_GETS_NO_MEMOS
	%s ne peut recevoir de memos.
MEMO_X_HAS_TOO_MANY_MEMOS
	%s a trop de memos et ne peut en recevoir plus.
MEMO_SENT
	Memo envoy  %s.
	
# CANCEL responses
MEMO_CANCEL_SYNTAX
	CANCEL {nick | channel}
MEMO_CANCEL_DISABLED
	Dsols, l'annulation de memos est temporairement dsactive
MEMO_CANCEL_NONE
	Aucun memo n'tait annulable.
MEMO_CANCELLED
	Le dernier memo envoy  %s a t supprim.

# LIST responses
MEMO_LIST_SYNTAX
	LIST [channel] [liste | NEW]
MEMO_HAVE_NO_NEW_MEMOS
	Vous n'avez pas de nouveaux memos.
MEMO_X_HAS_NO_NEW_MEMOS
	%s n'a pas de nouveaux memos.
MEMO_LIST_MEMOS
	Memos pour %s.  Pour lire, tapez: /msg %s READ num
MEMO_LIST_NEW_MEMOS
	Nouveaux memos pour %s.  Pour lire, tapez: /msg %s READ num
MEMO_LIST_CHAN_MEMOS
	Memos pour %s.  Pour lire, tapez: /msg %s READ %s num
MEMO_LIST_CHAN_NEW_MEMOS
	Nouveaux memos pour %s.  Pour lire, tapez: /msg %s READ %s num
MEMO_LIST_HEADER
	 Num  Expditeur        Date/Heure
MEMO_LIST_FORMAT
	%c%3d  %-16s  %s

# READ responses
MEMO_READ_SYNTAX
	READ [channel] {liste | LAST | NEW}
MEMO_HEADER
	Memo %d de %s (%s).  Pour supprimer, tapez: /msg %s DEL %d
MEMO_CHAN_HEADER
	Memo %d de %s (%s).  Pour supprimer, tapez: /msg %s DEL %s %d
MEMO_TEXT
	%s

# DEL responses
MEMO_DEL_SYNTAX
	DEL [channel] {num | liste | ALL}
MEMO_DELETED_NONE
	Aucun memo supprim.
MEMO_DELETED_ONE
	Le memo %d a t supprim.
MEMO_DELETED_SEVERAL
	Les memos %s ont t supprims.
MEMO_DELETED_ALL
	Tous vos memos ont t supprims.

# SET responses
MEMO_SET_SYNTAX
	SET option paramtres
MEMO_SET_DISABLED
	Dsols, la configuration des options est temporairement dsactive.
MEMO_SET_UNKNOWN_OPTION
	Option SET %s inconnue.

# SET NOTIFY responses
MEMO_SET_NOTIFY_SYNTAX
	SET NOTIFY {ON | LOGON | NEW | OFF}
MEMO_SET_NOTIFY_ON
	%s vous notifiera maintenant des memos quand vous vous connectez et quand ils vous sont envoys.
MEMO_SET_NOTIFY_LOGON
	%s vous notifiera maintenant des memos quand vous vous connectez ou enlevez /AWAY.
MEMO_SET_NOTIFY_NEW
	%s vous notifiera maintenant des memos quand ils vous sont envoys.
MEMO_SET_NOTIFY_OFF
	%s ne vous enverra aucune notification de memos.

# SET LIMIT responses
MEMO_SET_LIMIT_SYNTAX
	SET LIMIT [channel] limite
MEMO_SET_LIMIT_SERVADMIN_SYNTAX
	SET LIMIT [utilisateur | channel] {limite | NONE} [HARD]
MEMO_SET_YOUR_LIMIT_FORBIDDEN
	Vous n'tes pas autoris  changer votre limite de memos.
MEMO_SET_LIMIT_FORBIDDEN
	La limite de memos pour %s ne peut tre change.
MEMO_SET_YOUR_LIMIT_TOO_HIGH
	Vous ne pouvez mettre votre limite de memos  plus de %d.
MEMO_SET_LIMIT_TOO_HIGH
	Vous ne pouvez mettre la limite de memos de %s  plus de %d.
MEMO_SET_LIMIT_OVERFLOW
	Limite de memos trop grande; limitation  %d.
MEMO_SET_YOUR_LIMIT
	Votre limite de memos a t place  %d.
MEMO_SET_YOUR_LIMIT_ZERO
	Vous ne pourrez dsormais plus recevoir de memos.
MEMO_UNSET_YOUR_LIMIT
	Votre limite de memos a t dsactive.
MEMO_SET_LIMIT
	Limite de memos de %s dfinie  %d.
MEMO_SET_LIMIT_ZERO
	Limite de memos de %s dfinie  0.
MEMO_UNSET_LIMIT
	Limite de memos de %s dsactive.

# INFO responses
MEMO_INFO_SYNTAX
	INFO [channel]
MEMO_INFO_SERVADMIN_SYNTAX
	INFO [nick | channel]
MEMO_INFO_NO_MEMOS
	Vous n'avez aucun memo actuellement.
MEMO_INFO_MEMO
	Vous avez actuellement 1 memo.
MEMO_INFO_MEMO_UNREAD
	Vous avez actuellement 1 memo, qui n'a pas encore t lu.
MEMO_INFO_MEMOS
	Vous avez actuellement %d memos.
MEMO_INFO_MEMOS_ONE_UNREAD
	Vous avez actuellement %d memos, desquels 1 n'a pas t lu.
MEMO_INFO_MEMOS_SOME_UNREAD
	Vous avez actuellement %d memos, desquels %d n'ont pas t lus.
MEMO_INFO_MEMOS_ALL_UNREAD
	Vous avez actuellement %d memos; aucun d'entre eux n'a t lu.
MEMO_INFO_LIMIT
	Votre limite de memos est de %d.
MEMO_INFO_HARD_LIMIT
	Votre limite de memos est de %d, et ne peut tre change.
MEMO_INFO_LIMIT_ZERO
	Votre limite de memos est de 0; vous ne recevrez aucun nouveau memo.
MEMO_INFO_HARD_LIMIT_ZERO
	Votre limite de memos est de 0; vous ne recevrez aucun nouveau memo.  Vous ne pouvez pas changer cette limite.
MEMO_INFO_NO_LIMIT
	Vous n'avez aucune limite sur le nombre de memos que vous pouvez garder.
MEMO_INFO_X_NO_MEMOS
	%s n'a actuellement aucun memo.
MEMO_INFO_X_MEMO
	%s a actuellement 1 memo.
MEMO_INFO_X_MEMO_UNREAD
	%s a actuellement 1 memo, qui n'a pas encore t lu.
MEMO_INFO_X_MEMOS
	%s a actuellement %d memos.
MEMO_INFO_X_MEMOS_ONE_UNREAD
	%s a actuellement %d memos, desquels 1 n'a pas t lu.
MEMO_INFO_X_MEMOS_SOME_UNREAD
	%s a actuellement %d memos, desquels %d n'ont pas t lus.
MEMO_INFO_X_MEMOS_ALL_UNREAD
	%s a actuellement %d memos; desquels aucun n'a t lu.
MEMO_INFO_X_LIMIT
	La limite de memos de %s est de %d.
MEMO_INFO_X_HARD_LIMIT
	La limite de memos de %s est de %d.
MEMO_INFO_X_NO_LIMIT
	%s n'a aucune limitation de memos.

###########################################################################
#
# BotServ messages
#
###########################################################################
	
# Standard responses
BOT_DOES_NOT_EXIST
	Le bot %s n'existe pas.
BOT_NOT_ASSIGNED
	Vous devez attribuer un bot au channel avant d'utiliser 
	cette commande.
	Tapez /msg %S HELP ASSIGN pour plus d'informations.
BOT_NOT_ON_CHANNEL
	Le bot n'est pas sur le channel %s.
	
# Kick reasons (must be a single line)
BOT_REASON_BADWORD
	Ne dites pas %s sur ce channel!
BOT_REASON_BOLD
	N'utilisez pas de caractres gras sur ce channel!
BOT_REASON_CAPS
	Dsactivez le Caps Lock!
BOT_REASON_COLOR
	N'utilisez pas de couleurs sur ce channel!
BOT_REASON_FLOOD
	Arrtez de flooder!
BOT_REASON_REPEAT
	Arrtez de vous rpter!
BOT_REASON_REVERSE
	N'utilisez pas de reverses sur ce channel!
BOT_REASON_UNDERLINE
	N'utilisez pas de caractres souligns sur ce channel!
	
# BOT responses
BOT_BOT_SYNTAX
	BOT ADD nick user host real
	BOT CHANGE oldnick newnick [user [host [real]]]
	BOT DEL nick
	BOT LIST
BOT_BOT_ALREADY_EXISTS
	Le bot %s existe dj.
BOT_BOT_CREATION_FAILED
	Dsols, la cration du bot a chou.
BOT_BOT_READONLY
	Dsols, la modification des bots est temporairement dsactive.
BOT_BOT_ADDED
	%s!%s@%s (%s) ajout  la liste des bots.
BOT_BOT_ANY_CHANGES
	L'ancienne information est gale  la nouvelle.
BOT_BOT_CHANGED
	Le bot %s a t chang en %s!%s@%s (%s)
BOT_BOT_DELETED
	Le bot %s a t supprim.
	
# BOTLIST responses
BOT_BOTLIST_HEADER
	Liste des bots:
BOT_BOTLIST_EMPTY
	Il n'y a aucun bot disponible actuellement.
	Demandez  un Services admin d'en crer un!
	
# ASSIGN responses
BOT_ASSIGN_SYNTAX
	ASSIGN chan nick
BOT_ASSIGN_READONLY
	Dsols, l'attribution des bots est temporairement dsactive.
BOT_ASSIGN_ALREADY
	Le channel %s a dj un bot attribu.
BOT_ASSIGN_ASSIGNED
	Le bot %s a t attribu  %s.
	
# UNASSIGN responses
BOT_UNASSIGN_SYNTAX
	UNASSIGN chan
BOT_UNASSIGN_UNASSIGNED
	Il n'y a plus de bot attribu  %s.
	
# INFO responses
BOT_INFO_SYNTAX
	INFO {chan | nick}
BOT_INFO_NOT_FOUND
	%s n'est pas un bot ou channel enregistr valide.
BOT_INFO_BOT_HEADER
	Information pour le bot %s:
BOT_INFO_BOT_MASK
	      Masque : %s@%s
BOT_INFO_BOT_REALNAME
	    Vrai nom : %s
BOT_INFO_BOT_CREATED
	        Cr : %s
BOT_INFO_BOT_USAGE
	 Utilis sur : %d channel(s)
BOT_INFO_CHAN_HEADER
	Information pour le channel %s:
BOT_INFO_CHAN_BOT
	             Nick du bot : %s
BOT_INFO_CHAN_BOT_NONE
	             Nick du bot : non attribu.
BOT_INFO_CHAN_KICK_BADWORDS
	Kicker de mots interdits : %s
BOT_INFO_CHAN_KICK_BADWORDS_BAN
	Kicker de mots interdits : %s (%d kick(s) pour un ban)
BOT_INFO_CHAN_KICK_BOLDS
	     Kicker de car. gras : %s
BOT_INFO_CHAN_KICK_BOLDS_BAN
	     Kicker de car. gras : %s (%d kick(s) pour un ban)
BOT_INFO_CHAN_KICK_CAPS_ON
	    Kicker de majuscules : %s (minimum %d/%d%%)
BOT_INFO_CHAN_KICK_CAPS_BAN
	    Kicker de majuscules : %s (%d kick(s) pour un ban; minimum %d/%d%%)
BOT_INFO_CHAN_KICK_CAPS_OFF
	    Kicker de majuscules : %s
BOT_INFO_CHAN_KICK_COLORS
	      Kicker de couleurs : %s
BOT_INFO_CHAN_KICK_COLORS_BAN
	      Kicker de couleurs : %s (%d kick(s) pour un ban)
BOT_INFO_CHAN_KICK_FLOOD_ON
	         Kicker de flood : %s (%d lignes en %ds)
BOT_INFO_CHAN_KICK_FLOOD_BAN
	         Kicker de flood : %s (%d kick(s) pour un ban; %d lignes en %ds)
BOT_INFO_CHAN_KICK_FLOOD_OFF
	         Kicker de flood : %s
BOT_INFO_CHAN_KICK_REPEAT_ON
	    Kicker de rptition : %s (%d fois)
BOT_INFO_CHAN_KICK_REPEAT_BAN
	    Kicker de rptition : %s (%d kick(s) pour un ban; %d fois)
BOT_INFO_CHAN_KICK_REPEAT_OFF
	    Kicker de rptition : %s
BOT_INFO_CHAN_KICK_REVERSES
	      Kicker de reverses : %s
BOT_INFO_CHAN_KICK_REVERSES_BAN
	      Kicker de reverses : %s (%d kick(s) pour un ban)
BOT_INFO_CHAN_KICK_UNDERLINES
	Kicker de car. souligns : %s
BOT_INFO_CHAN_KICK_UNDERLINES_BAN
	Kicker de car. souligns : %s (%d kick(s) pour un ban)
BOT_INFO_ACTIVE
	actif
BOT_INFO_INACTIVE
	inactif
BOT_INFO_CHAN_OPTIONS
	                 Options : %s
BOT_INFO_OPT_DONTKICKOPS
	Protection des ops
BOT_INFO_OPT_DONTKICKVOICES
	Protection des voices
BOT_INFO_OPT_FANTASY
	Fantaisie
BOT_INFO_OPT_GREET
	Message d'accueil
BOT_INFO_OPT_SYMBIOSIS
	Symbiose
BOT_INFO_OPT_NONE
	Aucune
	
# SET responses
BOT_SET_SYNTAX
	SET channel option paramtres
BOT_SET_DISABLED
	Dsols, la configuration des options du bot est 
	temporairement dsactive.
BOT_SET_UNKNOWN
	Option %s inconnue.
	Tapez /msg %S HELP SET pour plus d'informations.
	
# SET DONTKICKOPS messages
BOT_SET_DONTKICKOPS_SYNTAX
	SET channel DONTKICKOPS {ON|OFF}
BOT_SET_DONTKICKOPS_ON
	Le bot ne kickera pas les ops du channel %s.
BOT_SET_DONTKICKOPS_OFF
	Le bot kickera les ops du channel %s.
	
# SET DONTKICKVOICES messages
BOT_SET_DONTKICKVOICES_SYNTAX
	SET channel DONTKICKVOICES {ON|OFF}
BOT_SET_DONTKICKVOICES_ON
	Le bot ne kickera pas les voices du channel %s.
BOT_SET_DONTKICKVOICES_OFF
	Le bot kickera les voices du channel %s.

# SET FANTASY messages
BOT_SET_FANTASY_SYNTAX
	SET channel FANTASY {ON|OFF}
BOT_SET_FANTASY_ON
	La fantaisie est maintenant active sur le channel %s.
BOT_SET_FANTASY_OFF
	La fantaisie est maintenant dsactive sur le channel %s.
	
# SET GREET messages
BOT_SET_GREET_SYNTAX
	SET channel GREET {ON|OFF}
BOT_SET_GREET_ON
	Le message d'accueil est maintenant activ sur le channel %s.
BOT_SET_GREET_OFF
	Le message d'accueil est maintenant dsactiv sur le channel %s.
	
# SET SYMBIOSIS
BOT_SET_SYMBIOSIS_SYNTAX
	SET channel SYMBIOSIS {ON|OFF}
BOT_SET_SYMBIOSIS_ON
	La symbiose est maintenant active sur le channel %s.
BOT_SET_SYMBIOSIS_OFF
	La symbiose est maintenant dsactive sur le channel %s.
	
# KICK responses
BOT_KICK_SYNTAX
	KICK channel option {ON|OFF} [paramtres]
BOT_KICK_DISABLED
	Dsols, la configuration des kickers est temporairement
	dsactive.
BOT_KICK_UNKNOWN
	Option %s inconnue.
	Tapez /msg %S HELP KICK pour plus d'informations.
BOT_KICK_NO_COLORS
	Sur ce rseau, le kicker de couleurs est dsactiv. Vous
	devez bloquer le mode c avec la commande SET MLOCK de
	%s pour empcher les utilisateurs d'utiliser des
	couleurs. 
BOT_KICK_BAD_TTB
	%s ne peut tre pris comme nombre de fois pour un ban.

BOT_KICK_BADWORDS_ON
	Le bot kickera maintenant les mots interdits. Utilisez
	la commande BADWORDS pour ajouter ou supprimer un mot.
BOT_KICK_BADWORDS_ON_BAN
	Le bot kickera maintenant les mots interdits, et mettra
	un ban aprs %d kicks pour le mme utilisateur. Utilisez
	la commande BADWORDS pour ajouter ou supprimer un mot.
BOT_KICK_BADWORDS_OFF
	Le bot ne kickera plus les mots interdits.
BOT_KICK_BOLDS_ON
	Le bot kickera maintenant les caractres gras.
BOT_KICK_BOLDS_ON_BAN
	Le bot kickera maintenant les caractres gras, et mettra
	un ban aprs %d kicks pour le mme utilisateur.
BOT_KICK_BOLDS_OFF
	Le bot ne kickera plus les caractres gras.
BOT_KICK_CAPS_ON
	Bot will now kick caps (they must constitute at least
	%d characters and %d%% of the entire message).
	Le bot kickera maintenant les majuscules (qui doivent
	constituer au moins %d caractres et %d%% du message 
	entier).
BOT_KICK_CAPS_ON_BAN
	Le bot kickera maintenant les majuscules (qui doivent
	constituer au moins %d caractres et %d%% du message 
	entier), et mettra un ban aprs %d kicks pour le mme 
	utilisateur.
BOT_KICK_CAPS_OFF
	Le bot ne kickera plus les majuscules.
BOT_KICK_COLORS_ON
	Le bot kickera maintenant les couleurs.
BOT_KICK_COLORS_ON_BAN
	Le bot kickera maintenant les couleurs, et mettra
	un ban aprs %d kicks pour le mme utilisateur.
BOT_KICK_COLORS_OFF
	Le bot ne kickera plus les couleurs.
BOT_KICK_FLOOD_ON
	Le bot kickera maintenant le flood (%d lignes en %d 
	secondes).
BOT_KICK_FLOOD_ON_BAN
	Le bot kickera maintenant le flood (%d lignes en %d 
	secondes), et mettra un ban aprs %d kicks pour le 
	mme utilisateur.
BOT_KICK_FLOOD_OFF
	Le bot ne kickera plus le flood.
BOT_KICK_REPEAT_ON
	Le bot kickera maintenant les rptitions (les 
	utilisateurs qui disent %d fois la mme chose).
BOT_KICK_REPEAT_ON_BAN
	Le bot kickera maintenant les rptitions (les 
	utilisateurs qui disent %d fois la mme chose), et 
	mettra un ban aprs %d kicks pour le  mme utilisateur.
BOT_KICK_REPEAT_OFF
	Le bot ne kickera plus les rptitions.
BOT_KICK_REVERSES_ON
	Le bot kickera maintenant les reverses.
BOT_KICK_REVERSES_ON_BAN
	Le bot kickera maintenant les reverses, et mettra
	un ban aprs %d kicks pour le mme utilisateur.
BOT_KICK_REVERSES_OFF
	Le bot ne kickera plus les reverses.
BOT_KICK_UNDERLINES_ON
	Le bot kickera maintenant les caractres souligns.
BOT_KICK_UNDERLINES_ON_BAN
	Le bot kickera maintenant les caractres souligns, 
	et mettra un ban aprs %d kicks pour le mme 
	utilisateur.
BOT_KICK_UNDERLINES_OFF
	Le bot ne kickera plus les caractres souligns.
	
# BADWORDS messages
BOT_BADWORDS_SYNTAX
	BADWORDS channel {ADD|DEL|LIST|CLEAR} [nick | entry-list]
BOT_BADWORDS_DISABLED
	Dsols, la modification de la liste des mots interdits
	est temporairement dsactive.
BOT_BADWORDS_REACHED_LIMIT
	Dsols, vous ne pouvez avoir que %d entres sur la
	liste des mots interdits.
BOT_BADWORDS_ALREADY_EXISTS
	%s existe dj dans la liste des mots interdits de %s.
BOT_BADWORDS_ADDED
	%s ajout  la liste des mots interdits de %s.
BOT_BADWORDS_NO_SUCH_ENTRY
	Entre (#%d) introuvable sur la liste des mots 
	interdits de %s.
BOT_BADWORDS_NOT_FOUND
	%s introuvable sur la liste des mots interdits de %s.
BOT_BADWORDS_NO_MATCH
	Aucune entre correspondante sur la liste des mots interdits 
	de %s.
BOT_BADWORDS_DELETED
	%s supprim de la liste des mots interdits de %s.
BOT_BADWORDS_DELETED_ONE
	1 entre supprime de la liste des mots interdits de %s.
BOT_BADWORDS_DELETED_SEVERAL
	%d entres supprimes de la liste des mots interdits de %s.
BOT_BADWORDS_LIST_EMPTY
	La liste des mots interdits de %s est vide.
BOT_BADWORDS_LIST_HEADER
	Liste des mots interdits de %s:
	  Num   Mot                            Type
BOT_BADWORDS_LIST_FORMAT
	  %3d   %-30s %s
BOT_BADWORDS_CLEAR
	La liste des mots interdits est maintenant vide.

# SAY responses
BOT_SAY_SYNTAX
	SAY channel texte
	
# ACT responses
BOT_ACT_SYNTAX
	ACT channel texte

###########################################################################
#
# OperServ messages
#
###########################################################################

# General messages
OPER_BOUNCY_MODES
	Les Services ne peuvent changer les modes. Vos serveurs sont-ils configurs correctement?
OPER_BOUNCY_MODES_U_LINE
	Les Services ne peuvent changer les modes. Les U:lines de vos serveurs sont-elles configures correctement?

# GLOBAL responses
OPER_GLOBAL_SYNTAX
	GLOBAL message

# STATS responses
OPER_STATS_UNKNOWN_OPTION
	Option STATS inconnus %s.
OPER_STATS_CURRENT_USERS
	Utilisateurs courants: %d (%d ops)
OPER_STATS_MAX_USERS
	Utilisateurs maximum: %d (%s)
# This is ugly, but at least it's language-portable...
# Note that you can include seconds in any of these--my personal preference
# is to only give resolution to the nearest minute when uptime is one hour
# or more, but just add a %d to get seconds as well.
OPER_STATS_UPTIME_DHMS
	Les services tournent depuis %d jours, %02d:%02d
OPER_STATS_UPTIME_1DHMS
	Les services tournent depuis %d jour, %02d:%02d
OPER_STATS_UPTIME_HMS
	Les services tournent depuis %d heures, %d minutes
OPER_STATS_UPTIME_HM1S
	Les services tournent depuis %d heures, %d minutes
OPER_STATS_UPTIME_H1MS
	Les services tournent depuis %d heures, %d minute
OPER_STATS_UPTIME_H1M1S
	Les services tournent depuis %d heures, %d minute
OPER_STATS_UPTIME_1HMS
	Les services tournent depuis %d heure, %d minutes
OPER_STATS_UPTIME_1HM1S
	Les services tournent depuis %d heure, %d minutes
OPER_STATS_UPTIME_1H1MS
	Les services tournent depuis %d heure, %d minute
OPER_STATS_UPTIME_1H1M1S
	Les services tournent depuis %d heure, %d minute
OPER_STATS_UPTIME_MS
	Les services tournent depuis %d minutes, %d secondes
OPER_STATS_UPTIME_M1S
	Les services tournent depuis %d minutes, %d seconde
OPER_STATS_UPTIME_1MS
	Les services tournent depuis %d minute, %d secondes
OPER_STATS_UPTIME_1M1S
	Les services tournent depuis %d minute, %d seconde
OPER_STATS_BYTES_READ
	Octets lus   : %5d kB
OPER_STATS_BYTES_WRITTEN
	Octets crits: %5d kB
OPER_STATS_USER_MEM
	Utilisateur  : %6d enregistrements, %5d kB
OPER_STATS_CHANNEL_MEM
	Channel      : %6d enregistrements, %5d kB
OPER_STATS_NICKSERV_MEM
	NickServ     : %6d enregistrements, %5d kB
OPER_STATS_CHANSERV_MEM
	ChanServ     : %6d enregistrements, %5d kB
OPER_STATS_BOTSERV_MEM
	BotServ      : %6d enregistrements, %5d kB
OPER_STATS_OPERSERV_MEM
	OperServ     : %6d enregistrements, %5d kB
OPER_STATS_SESSIONS_MEM
	Sessions     : %6d enregistrements, %5d kB
OPER_STATS_AKILL_COUNT
	Nombre d'AKILLs actuel: %d
OPER_STATS_AKILL_EXPIRE_DAYS
	Temps d'chance des AKILLs par dfaut: %d jours
OPER_STATS_AKILL_EXPIRE_DAY
	Temps d'chance des AKILLs par dfaut: 1 jour
OPER_STATS_AKILL_EXPIRE_HOURS
	Temps d'chance des AKILLs par dfaut: %d heures
OPER_STATS_AKILL_EXPIRE_HOUR
	Temps d'chance des AKILLs par dfaut: 1 heure
OPER_STATS_AKILL_EXPIRE_MINS
	Temps d'chance des AKILLs par dfaut: %d minutes
OPER_STATS_AKILL_EXPIRE_MIN
	Temps d'chance des AKILLs par dfaut: 1 minute
OPER_STATS_AKILL_EXPIRE_NONE
	Temps d'chance des AKILLs par dfaut: Pas d'chance
OPER_STATS_RESET
	Statistiques rinitialises.

# MODE responses
OPER_MODE_SYNTAX
	MODE channel modes

# CLEARMODES responses
OPER_CLEARMODES_SYNTAX
	CLEARMODES channel [ALL]
OPER_CLEARMODES_DONE
	Les modes binaires et les bans sont supprims de %s.
OPER_CLEARMODES_ALL_DONE
	Tous les modes supprims du channel %s.


# KICK responses
OPER_KICK_SYNTAX
	KICK channel utilisateur raison

# ADMIN responses
OPER_ADMIN_SYNTAX
	ADMIN {ADD | DEL | LIST} [nick]
OPER_ADMIN_ADD_SYNTAX
	ADMIN ADD nick
OPER_ADMIN_DEL_SYNTAX
	ADMIN DEL nick
OPER_ADMIN_SKELETON
	Les services sont en modes skeleton. ADMIN n'est pas disponible.
OPER_ADMIN_EXISTS
	%s existe dj sur la Services admin list.
OPER_ADMIN_ADDED
	%s ajout  la Services admin list.
OPER_ADMIN_TOO_MANY
	Trop d'entres (%d) sur la Services admin list; ne peut en ajouter plus.
OPER_ADMIN_REMOVED
	%s supprim de la Services admin list.
OPER_ADMIN_NOT_FOUND
	%s non trouv sur la Services admin list.
OPER_ADMIN_LIST_HEADER
	Services admin list:

# OPER responses
OPER_OPER_SYNTAX
	OPER {ADD | DEL | LIST} [nick]
OPER_OPER_ADD_SYNTAX
	OPER ADD nick
OPER_OPER_DEL_SYNTAX
	OPER DEL nick
OPER_OPER_SKELETON
	Les Services sont en mode Skeleton; la commande OPER est indisponible.
OPER_OPER_EXISTS
	%s existe dj sur la Services operator list.
OPER_OPER_ADDED
	%s ajout  la Services operator list.
OPER_OPER_TOO_MANY
	Trop d'entres (%d) sur la Services operator list; ne peut en ajouter d'autres.
OPER_OPER_REMOVED
	%s supprim de la Services operator list.
OPER_OPER_NOT_FOUND
	%s non trouv sur la Services operator list.
OPER_OPER_LIST_HEADER
	Services operator list:

# AKILL responses
OPER_AKILL_SYNTAX
	AKILL {ADD | DEL | LIST | VIEW} [[+chance] mask [raison]]
OPER_AKILL_ADD_SYNTAX
	AKILL ADD [+chance] mask raison
OPER_AKILL_DEL_SYNTAX
	AKILL DEL mask
OPER_TOO_MANY_AKILLS
	AKILL list pleine!
OPER_AKILL_NO_NICK
	Rappel: les masks d'AKILL ne peuvent contenir de nicks; assurez vous de ne pas avoir inclus de nick dans votre mask. 
OPER_AKILL_ADDED
	%s ajout  l'AKILL list.
OPER_AKILL_REMOVED
	%s supprim de l'AKILL list.
OPER_AKILL_NOT_FOUND
	%s non trouv sur l'AKILL list.
OPER_AKILL_LIST_HEADER
	AKILL list actuelle:
# mask, reason
OPER_AKILL_LIST_FORMAT
	%-32s  %s
# mask, set-by, set-time, expires, reason
OPER_AKILL_VIEW_FORMAT
	%s (par %s le %s; %s)
	    %s
OPER_AKILL_NO_EXPIRE
	n'expire pas
OPER_AKILL_EXPIRES_SOON
	expire  la prochaine mise  jour de la base de donnes
OPER_AKILL_EXPIRES_M
	expire dans %d minutes
OPER_AKILL_EXPIRES_1M
	expire dans %d minute
OPER_AKILL_EXPIRES_HM
	expire dans %d heures, %d minutes
OPER_AKILL_EXPIRES_H1M
	expire dans %d heures, %d minute
OPER_AKILL_EXPIRES_1HM
	expire dans %d heure, %d minutes
OPER_AKILL_EXPIRES_1H1M
	expire dans %d heure, %d minute
OPER_AKILL_EXPIRES_D
	expire dans %d jours
OPER_AKILL_EXPIRES_1D
	expire dans %d jour

# SET responses
OPER_SET_SYNTAX
	SET option valeur
OPER_SET_IGNORE_ON
	Le code d'ignore sera utilis.
OPER_SET_IGNORE_OFF
	Le code d'ignore ne sera pas utilis.
OPER_SET_IGNORE_ERROR
	La valeur pour IGNORE doit tre ON ou OFF.
OPER_SET_READONLY_ON
	Les Services sont maintenant en mode lecture-seule.
OPER_SET_READONLY_OFF
	Les Services sont maintenant en mode lecture-criture.
OPER_SET_READONLY_ERROR
	La valeur pour READONLY doit tre ON ou OFF.
OPER_SET_DEBUG_ON
	Les Services sont maintenant en debug mode.
OPER_SET_DEBUG_OFF
	Les Services sont maintenant en non-debug mode.
OPER_SET_DEBUG_LEVEL
	Les Services sont maintenant en debug mode (level %d).
OPER_SET_DEBUG_ERROR
	La valeur pour DEBUG doit tre ON, OFF, ou un nombre positif.
OPER_SET_NOEXPIRE_ON
	Les Services sont maintenant en mode sans expiration.
OPER_SET_NOEXPIRE_OFF
	Les Services sont maintenant en mode expiration.
OPER_SET_NOEXPIRE_ERROR
	La valeur de NOEXPIRE doit tre ON ou OFF.
OPER_SET_UNKNOWN_OPTION
	Option inconnue %s.

# JUPE responses
OPER_JUPE_SYNTAX
	JUPE nomduserveur [raison]

# RAW responses
OPER_RAW_SYNTAX
	RAW texte

# UPDATE responses
OPER_UPDATING
	Mise  jour des bases de donnes.

# RESTART responses
OPER_CANNOT_RESTART
	SERVICES_BIN non dfini; ne peut redmarrer.  Relancez le script \2configure\2 et recompilez les Services pour activer la commande RESTART.

# LISTIGNORE responses
OPER_IGNORE_LIST
	Services ignore list:
OPER_IGNORE_LIST_EMPTY
	L'ignore list est vide.
	
# KILLCLONES responses
OPER_KILLCLONES_SYNTAX
	KILLCLONES nick
OPER_KILLCLONES_UNKNOWN_NICK
	Impossible de trouver l'utilisateur %s.
	
# CHANLIST responses
OPER_CHANLIST_HEADER
	Liste des channels:
	Nom                  Users Topic
OPER_CHANLIST_HEADER_USER
	Liste des channels de %s:
	Nom                  Users Topic
OPER_CHANLIST_RECORD
	%-20s  %4d %s
OPER_CHANLIST_END
	Fin de la liste des channels.
	
# USERLIST responses
OPER_USERLIST_HEADER
	Liste des utilisateurs:
	Nick                 Masque
OPER_USERLIST_HEADER_CHAN
	Liste des utilisateurs de %s:
	Nick                 Masque
OPER_USERLIST_RECORD
	%-20s %s@%s
OPER_USERLIST_END
	Fin de la liste des utilisateurs.
	
###########################################################################
#
# Session Limiting and Exception messages
#
###########################################################################

# EXCEPTION responses
OPER_EXCEPTION_SYNTAX
	EXCEPTION {ADD | DEL | MOVE | LIST | VIEW} [paramtres]
OPER_EXCEPTION_ADD_SYNTAX
	EXCEPTION ADD [+chance] mask limite raison
OPER_EXCEPTION_DEL_SYNTAX
	EXCEPTION DEL {mask | liste}
OPER_EXCEPTION_MOVE_SYNTAX
	EXCEPTION MOVE num position
OPER_EXCEPTION_DISABLED
	La limitation de sessions est dsactive.
OPER_EXCEPTION_ALREADY_PRESENT
	Le mask %s est dj prsent sur la liste d'exceptions.
OPER_EXCEPTION_TOO_MANY
	La liste des exceptions  la limitation de sessions est pleine!
OPER_EXCEPTION_ADDED
	La limite de sessions de %s est maintenant de %d.
OPER_EXCEPTION_MOVED
	L'exception pour %s (#%d) a t dplace  la position %d.
OPER_EXCEPTION_NO_SUCH_ENTRY
	L'entre %d n'existe pas sur la liste des exceptions  la limitation de sessions.
OPER_EXCEPTION_NOT_FOUND
	%s non trouv sur la liste des exceptions  la limitation de sessions.
OPER_EXCEPTION_NO_MATCH
	Aucune entre correspondante sur la liste des exceptions  la limitation de sessions.
OPER_EXCEPTION_DELETED
	%s supprim de la liste des exceptions  la limitation de sessions.
OPER_EXCEPTION_DELETED_ONE
	1 entre supprime de la liste des exceptions  la limitation de sessions.
OPER_EXCEPTION_DELETED_SEVERAL
	%d entres supprimes de la liste des exceptions  la limitation de sessions.
OPER_EXCEPTION_LIST_HEADER
	Liste actuelle des exceptions  la limitation de sessions:
# mask, limit
OPER_EXCEPTION_LIST_FORMAT
	%3d  %4d    %s
OPER_EXCEPTION_LIST_COLHEAD
	Num  Limite  Host
# mask, set-by, set-time, expires, limit, reason
OPER_EXCEPTION_VIEW_FORMAT
	%3d.  %s  (par %s le %s; %s)
	    Limite: %-4d  - %s
OPER_EXCEPTION_INVALID_LIMIT
	Limite de session invalide. Elle doit tre un entier valide suprieur ou gal  zero et plus petit que %d.
OPER_EXCEPTION_INVALID_HOSTMASK
	Hostmask invalide. Seuls les hostmasks rels sont valides puisque les exceptions ne sont pas compars aux nicks et usernames.

# SESSION responses
OPER_SESSION_SYNTAX
	SESSION {LIST limite | VIEW host}
OPER_SESSION_LIST_SYNTAX
	SESSION LIST limite
OPER_SESSION_VIEW_SYNTAX
	SESSION VIEW host
OPER_SESSION_DISABLED
	La limitation de session est dsactive.
OPER_SESSION_INVALID_THRESHOLD
	Valeur minimale invalide. Elle doit tre un entier valide suprieur  1.
OPER_SESSION_NOT_FOUND
	%s introuvable sur la liste des sessions.
OPER_SESSION_LIST_HEADER
	Hosts ayant au moins %d sessions:
OPER_SESSION_LIST_COLHEAD
	Sessions  Host
# limit, host
OPER_SESSION_LIST_FORMAT
	%6d    %s
# host, sessions, limit
OPER_SESSION_VIEW_FORMAT
	L'host %s a actuellement %d sessions avec une limite de %d.

# EXCEPTION help

OPER_HELP_EXCEPTION
	Syntax: EXCEPTION ADD [+chance] mask limite raison
	        EXCEPTION DEL {mask | liste}
	        EXCEPTION MOVE num position
	        EXCEPTION LIST [mask | liste]
	        EXCEPTION VIEW [mask | liste]
	
	Permet aux Services admins de manipuler la liste des hosts qui
	ont des limites de session spcifiques - autoriser certaines
	machines, telles que des servers de shell, pour supporter plus
	que le nombre de clients par dfaut  la fois. Une fois qu'une
	host atteint sa limite de session, tous les clients essayant
	de se connecter de cette host seront dconnects. Avant que
	l'utilisateur ne soit dconnect, ils sont avertis, par un
	/NOTICE d'OperServ, de l'endroit o ils pourront trouver de
	l'aide concernant la limitation de session. Le contenu de cette
	notice est une option de configuration.
	
	EXCEPTION ADD ajoute le mask donn  la liste des exceptions.
	Notez que les masks nick!user@host et user@host sont 
	invalides! Seuls les masks d'host rels, tels que box.host.dom 
	et *.host.dom, sont autoriss parce que la limitation de sessions
	ne prend pas en compte le nick ou l'username. limit doit tre un
	nombre suprieur ou gal  zero. Ceci dtermine combien de sessions
	sont supportes  la fois. Une valeur de zero signifie que l'host
	a une limite de sessions illimite. Consultez l'aide de AKILL pour
	les dtails sur le format du paramtre optionnel chance.
	EXCEPTION DEL supprime le mask donn de la liste des exceptions.
	EXCEPTION MOVE dplace l'exception num vers position. Les 
	exceptions se trouvant entre seront dplaces vers le haut ou le
	bas pour combler le trou.
	EXCEPTION LIST et EXCEPTION VIEW montrent toutes les 
	exceptions actuelles; si un mask optionnel est donn, la liste
	est limite aux exceptions correspondantes au mask. La diffrence
	est que EXCEPTION VIEW est plus informative, puisqu'elle affiche
	galement le nick de la personne qui a ajout l'exception, sa 
	limite de sessions, la raison, le mask ainsi que la date d'chance.
	
	Notez qu'un client se connectant "utilisera" la premire 
	exception  laquelle leur host correspond. Les
	grandes listes d'exception et les exceptions utilisant
	excessivement les wildcards entrainent une dgradation des
	performances des Services.
	
	Rserve Services admins.

OPER_HELP_SESSION
	Syntax: SESSION LIST minimal
	        SESSION VIEW host
	
	Permet aux Services admins de voir la liste des sessions.
	
	SESSION LIST liste les hosts ayant au minimum minimal
	sessions. La limite minimale doit tre un nombre suprieur 
	1. Ceci pour prvenir d'un listing accidentel d'un large
	nombre d'hosts  session unique.

	SESSION VIEW affiche des informations dtailles sur une
	host spcifique - comprenant le nombre de sessions actuelles
	ainsi que la limite de sessions. La valeur host ne doit
	pas contenir de wildcards.
		
	Consultez l'aide de EXCEPTION pour plus d'informations 
	concernant la limitation et comment dfinir les limites de
	sessions pour certaines hosts et groupes.
	
	Rserve aux Services admins.

###########################################################################
#
# News system messages
#
###########################################################################

NEWS_LOGON_TEXT
	[Logon News - %s] %s
NEWS_OPER_TEXT
	[Oper News - %s] %s

NEWS_LOGON_SYNTAX
	Syntaxe: LOGONNEWS {ADD|DEL|LIST} [texte|nombre]
NEWS_LOGON_LIST_HEADER
	Articles des logon news:
NEWS_LOGON_LIST_ENTRY
	%5d (%s par %s)
	    %s
NEWS_LOGON_LIST_NONE
	Il n'y a pas de logon news.
NEWS_LOGON_ADD_SYNTAX
	Syntaxe: LOGONNEWS ADD texte
NEWS_LOGON_ADD_FULL
	News list pleine!
NEWS_LOGON_ADDED
	Ajout un nouvel article de logon news (#%d).
NEWS_LOGON_DEL_SYNTAX
	Syntaxe: LOGONNEWS DEL {num | ALL}
NEWS_LOGON_DEL_NOT_FOUND
	Article de logon news #%d non trouv!
NEWS_LOGON_DELETED
	Article de logon news #%d supprim.
NEWS_LOGON_DEL_NONE
	Aucun article de logon news  supprimer!
NEWS_LOGON_DELETED_ALL
	Tous les articles de logon news supprims.

NEWS_OPER_SYNTAX
	Syntaxe: OPERNEWS {ADD|DEL|LIST} [texte|nombre]
NEWS_OPER_LIST_HEADER
	Articles oper news:
NEWS_OPER_LIST_ENTRY
	%5d (%s par %s)
	    %s
NEWS_OPER_LIST_NONE
	Il n'y a pas d'oper news.
NEWS_OPER_ADD_SYNTAX
	Syntaxe: OPERNEWS ADD texte
NEWS_OPER_ADD_FULL
	News list pleine!
NEWS_OPER_ADDED
	Ajout un nouvel article d'oper news (#%d).
NEWS_OPER_DEL_SYNTAX
	Syntaxe: OPERNEWS DEL {num | ALL}
NEWS_OPER_DEL_NOT_FOUND
	Article oper news #%d non trouv!
NEWS_OPER_DELETED
	Article oper news #%d supprim.
NEWS_OPER_DEL_NONE
	Pas d'articles oper news  supprimer!
NEWS_OPER_DELETED_ALL
	Tous les articles oper news supprims.

NEWS_HELP_LOGON
	Syntaxe: LOGONNEWS ADD texte
	         LOGONNEWS DEL {nombre | ALL}
	         LOGONNEWS LIST
	
	Edite ou affiche la liste de messages logon news. Lorsqu'un
	utilisateur se connecte au rseau, ces messages leur seront
	envoys. (Cependant, pas plus de trois messages ne seront
	envoys pour viter le flood des utilisateurs. Si il y a
	plus de trois messages de news, seuls les trois plus rcents
	seront envoys.)
	
	LOGONNEWS LIST peut tre utilise par tout IRc operator pour
	lister les messages de news courants. ADD et DEL peuvent
	uniquement tre utiliss par les Services admins.

NEWS_HELP_OPER
	Syntaxe: OPERNEWS ADD texte
	         OPERNEWS DEL {nombre | ALL}
	         OPERNEWS LIST
	
	Edite ou affiche la liste des messages oper news. Quand un
	utilisateur utilise la commande /OPER, ces messages lui seront
	envoys. (Cependant, pas plus de trois messages ne seront 
	envoys afin de ne pas flooder l'utilisateur. Si il y a plus
	de trois messages news, seuls les trois plus rcents seront
	envoys.)
	
	OPERNEWS LIST peut tre utilise par tout IRC operator pour
	lister les messages oper news actuels. ADD et DEL peuvent 
	uniquement tre utilises par les Services admins.

###########################################################################
#
# HelpServ help message
#
###########################################################################

HELP_HELP
	%S est un service conu pour donner des informations
	sur les Services. Les rubriques d'aide des Services sont
	accessibles par les commandes HELP des diffrents Services:

	/msg %s HELP
	     pour des informations sur l'enregistrement des nicks

	/msg %s HELP
	     pour des informations sur l'enregistrement et le
	     contrle des channels

	/msg %s HELP
	     pour des informations sur l'envoi de messages aux
	     utilisateurs non connects

###########################################################################
#
# NickServ help messages
#
###########################################################################

NICK_HELP
	%S vous permet d'enregistrer un nick et d'empcher les
	autres de l'utiliser. Si le nick n'est pas utilis pendant
	%d jours, l'enregistrement expirera. Les commandes suivantes
	permettent l'enregistrement et la gestion des nicks; pour
	les utiliser, tapez /msg %S commande. Pour plus
	d'informations sur une certaine commande, tapez
	/msg %S HELP commande.
	
	    REGISTER   Enregistre un nick
	    IDENTIFY   Vous identifie avec votre mot de passe
	    ACCESS     Modifie la liste des adresses autorises
	    LINK       Rend votre nick quivalent  un autre
	    SET        Configure les options, protection comprise
	    DROP       Annule l'enregistrement d'un nick
	    RECOVER    Change le nick d'un utilisateur qui a pris 
	               votre nick
	    RELEASE    Pour reprendre la tutelle de votre nick 
	               aprs un RECOVER
	    SENDPASS   A utiliser en cas de perte de mot de passe
	
	Autres commandes: UNLINK, GHOST, INFO, LIST, STATUS
	
	REMARQUE: Ce service est conu pour fournir un moyen aux
	utilisateurs IRC d'assurer que leur identit n'est pas
	usurpe. Il n'est PAS destin  faciliter le "vol" des
	nicks ou autres choses de ce genre. L'abus de %S entranera,
	au minimum, la perte du(des) nick(s) faisant l'objet de 
	l'abus.
	
NICK_HELP_EXPIRE_ZERO
	%S vous permet d'enregistrer un nick et d'empcher les
	autres de l'utiliser. Les commandes suivantes
	permettent l'enregistrement et la gestion des nicks; pour
	les utiliser, tapez /msg %S commande. Pour plus
	d'informations sur une certaine commande, tapez
	/msg %S HELP commande.
	
	    REGISTER   Enregistre un nick
	    IDENTIFY   Vous identifie avec votre mot de passe
	    ACCESS     Modifie la liste des adresses autorises
	    LINK       Rend votre nick quivalent  un autre
	    SET        Configure les options, protection comprise
	    DROP       Annule l'enregistrement d'un nick
	    RECOVER    Change le nick d'un utilisateur qui a pris 
	               votre nick
	    RELEASE    Pour reprendre la tutelle de votre nick 
	               aprs un RECOVER
	    SENDPASS   A utiliser en cas de perte de mot de passe
	
	Autres commandes: UNLINK, GHOST, INFO, LIST, STATUS
	
	REMARQUE: Ce service est conu pour fournir un moyen aux
	utilisateurs IRC d'assurer que leur identit n'est pas
	usurpe. Il n'est PAS destin  faciliter le "vol" des
	nicks ou autres choses de ce genre. L'abus de %S entranera,
	au minimum, la perte du(des) nick(s) faisant l'objet de 
	l'abus.

NICK_HELP_REGISTER
	Syntaxe: REGISTER motdepasse [email]
	
	Enregistre votre nick dans la base de donnes de %S. Une fois
	que votre nick est enregistr, vous pouvez utiliser les
	commandes SET et ACCESS pour configurer votre nick comme
	vous le souhaitez. Rappelez vous bien du mot de passe utilis
	pendant l'enregistrement - vous en aurez besoin pour effectuer
	des changements sur votre nick plus tard. (Notez que EPONA, 
	Epona, et epona sont tous des passwords diffrents!)
	
	Conseils pour choisir un mot de passe:
	
	Les mots de passe ne doivent pas tre trop facilement
	devinables. Par exemple, utiliser votre vrai nom comme
	mot de passe est une mauvaise ide. Utiliser votre nick
	comme mot de passe est une ide encore pire ;) et, en
	fait, %S ne le permettra pas. De mme, les mots de passe
	courts sont vulnrables aux recherches mthodiques,
	donc vous devez choisir un mot de passe d'au moins 
	5 caractres. Enfin, le caractre espace ne peut tre 
	utilis dans les mots de passe.
	
	Le paramtre email est optionnel et permet de dfinir
	un e-mail immdiatement. Toutefois, il peut tre obligatoire
	sur certains rseaux.

NICK_HELP_IDENTIFY
	Syntaxe: IDENTIFY motdepasse
	
	Informe %S que vous tes vraiment le propritaire de
	ce nick. Beaucoup de commandes demandent que vous soyez
	authentifi avec cette commande avant de les utiliser. Le
	mot de passe est celui que vous avez donn avec la commande 
	REGISTER.
	

NICK_HELP_DROP
	Syntaxe: DROP
	
	Efface votre nick de la base de donnes de %S. Un nick
	qui a t effac est libre d'tre renregistr par
	n'importe qui.
	
	Pour utiliser cette commande, vous devez d'abord vous
	identifier avec votre mot de passe (/msg %S HELP 
	IDENTIFY pour plus d'informations).


NICK_HELP_ACCESS
	Syntaxe: ACCESS ADD mask
	         ACCESS DEL mask
	         ACCESS LIST
	
	Modifie ou affiche la liste d'accs de votre nick. C'est
	la liste des adresses qui seront automatiquement reconnues
	par %S comme autorises  utiliser le nick. Si vous voulez
	utiliser le nick depuis une adresse diffrente, vous devez
	envoyer une commande IDENTIFY pour que %S vous reconnaisse.
	
	Exemples:
	
	    ACCESS ADD anyone@*.bepeg.com
	        Autorise l'accs  l'utilisateur anyone d'une
	        machine avec le domaine bepeg.com.
	
	    ACCESS DEL anyone@*.bepeg.com
	        Inverse la commande prcdente.
	
	    ACCESS LIST
	        Affiche votre liste d'accs.

NICK_HELP_LINK
	Syntaxe: LINK nick motdepasse
	
	Relie votre nick  un autre, rendant le nick que vous 
	utilisez actuellement l'quivalent du nick donn. Quand vous
	donnez cette commande, la liste d'accs du nick que vous 
	utilisez est supprime et remplace par celle du nick auquel
	vous vous reliez; tous les memos de votre nick sont ajouts
	 la liste de memos du nick cible (cela peut provoquer le
	dpassement de la limite de memos du nick, auquel cas vous
	devrez en supprimer quelques uns avant de pouvoir en recevoir
	d'autres pour l'un et l'autre nick).
	
	Une fois que la liaison a t tablie, votre nick sera 
	considr comme le nick cible partout dans les services, 
	sauf pour les commandes %S UNLINK et DROP. Par exemple, 
	vous pouvez utiliser l'un ou l'autre nick pour lire le mme 
	ensemble de memos (et les memos envoys  l'un ou l'autre 
	nick iront dans la mme liste). Si vous vous identifiez 
	pour un nick, vous serez automatiquement identifi pour l'autre. 
	Si un des nicks est sur la liste d'accs d'un channel, alors tous 
	les nicks auront les mmes privilges d'accs.
	
	Pour utiliser cette commande, vous devez vous identifier
	pour votre nick actuel (en utilisant la commande IDENTIFY),
	et vous devez fournir le mot de pass du nick auquel vous
	souhaitez vous relier.
	

NICK_HELP_UNLINK
	Syntaxe: UNLINK [nick motdepasse]
	
	Supprime une liaison de votre nick  un autre. Quand la liaison
	est supprime, les options et la liste d'accs du nick prcdemment
	relis sont copies vers votre nick courant et peuvent tre
	ensuite changs independamment. Les memos ne sont pas copis;
	tous les memos sont conservs sur le nick prcdemment reli.
	
	En donnant un nick et un mot de passe comme paramtres, vous
	pouvez dlier un nick du nick que vous utilisez actuellement.

NICK_HELP_SET
	Syntaxe: SET option paramtres
	
	Configure diverses options du nick. option peut tre:
	
	    PASSWORD   Change le mot de passe de votre nick
	    LANGUAGE   Change la langue dans laquelle les Services
	                   vous envoient leurs messages
	    URL        Associe une adresse de site  votre nick
	    EMAIL      Associe un e-mail  votre nick
	    GREET      Associe un message d'accueil  votre nick
	    KILL       Active ou dsactive la protection
	    SECURE     Active ou dsactive la scurit du nick
	    PRIVATE    Empche votre nick d'tre affich par
	                   /msg %S LIST
	    HIDE       Cache certaines parties des informations du nick
	
	Pour utiliser cette commande, vous devez d'abord vous
	identifier avec votre mot de passe (/msg %S HELP 
	IDENTIFY pour plus d'informations).
	
	Tapez /msg %S HELP SET option pour plus d'information
	sur une option spcifique.

NICK_HELP_SET_PASSWORD
	Syntaxe: SET PASSWORD nouveau-mot-de-passe
	
	Change le mot de passe utilis pour vous identifier en tant
	que propritaire du nick.

NICK_HELP_SET_LANGUAGE
	Syntaxe: SET LANGUAGE nombre
	
	Change la langue utilise par les Services lorsqu'ils vous
	envoient un message (par exemple, quand ils rpondent  une
	commande que vous avez envoy). nombre doit tre choisi
	dans la liste suivante des langues supportes:
	

NICK_HELP_SET_URL
	Syntaxe: SET URL adresse
	
	Associe l'adresse de votre site web  votre nick. Cette adresse 
	sera affiche lorsque quelqu'un demandera des informations sur
	votre nick avec la commande INFO.

NICK_HELP_SET_EMAIL
	Syntaxe: SET EMAIL adresse
	
	Associe l'e-mail donn avec votre nick. L'email
	sera affich lorsque quelqu'un demandera des informations 
	sur votre nick avec la commande INFO.
	
NICK_HELP_SET_GREET
	Syntaxe: SET GREET message
	
	Dfinit un message d'accueil pour votre nick, qui sera
	affich lorsque vous joignez un channel qui a l'option
	GREET active,  condition d'avoir un niveau d'accs
	suffisant.

NICK_HELP_SET_KILL
	Syntaxe: SET KILL {ON | QUICK | IMMED | OFF}
	
	Active ou dsactive la protection automatique
	pour votre nick. Avec la protection active, si
	un autre utilisateur essaie de prendre votre nick, il aura
	une minute pour changer de nick, aprs quoi son nick sera
	chang de force par %S.
	
	Si vous slectionnez QUICK, l'utilisateur aura seulement 20
	secondes pour changer de nick au lieu des 60 habituelles. Si
	vous slectionnez IMMED, l'utilisateur verra son nick chang 
	immdiatement sans tre d'abord prvenu et sans avoir de chance
	pour changer son nick; n'utilisez cette option que si ncessaire.
	De plus, les administrateurs de votre rseau peuvent avoir
	dsactiv cette option.

NICK_HELP_SET_SECURE
	Syntaxe: SET SECURE {ON | OFF}
	
	Active ou dsactive les caractristiques de scurit pour
	votre nick. Si la scurit est active, vous devrez obligatoirement
	entrer votre mot de passe pour tre reconnu en tant que 
	propritaire du nick, que votre masque soit dans la liste d'accs
	ou non. Cependant, si vous tes sur la liste d'accs, %S ignorera
	la configuration de la protection offerte par SET KILL.

NICK_HELP_SET_PRIVATE
	Syntaxe: SET PRIVATE {ON | OFF}
	
	Active ou dsactive le mode priv de votre nick.
	Si le mode priv est actif, votre nick n'apparaitra pas
	dans les listes de nicks gnres par la commande LIST
	de %S. (Cependant, quiconque connaissant votre nick peut
	tout de mme avoir des informations en utilisant
	la commande INFO).

NICK_HELP_SET_HIDE
	Syntaxe: SET HIDE {EMAIL | USERMASK | QUIT} {ON | OFF}
	
	Vous permet d'empcher l'affichage de certaines parties
	des informations quand quelqu'un fait un %S INFO sur votre
	nick. Vous pouvez cacher votre adresse e-mail (EMAIL), masque
	user@host vu pour la dernire fois (USERMASK), et la dernire
	raison de /QUIT (QUIT). Le second paramtre indique si 
	l'option doit tre affiche (OFF) ou cache (ON).

NICK_HELP_RECOVER
	Syntaxe: RECOVER nick [motdepasse]
	
	Vous permet de rcuprer votre nick si quelqu'un d'autre
	l'a pris; c'est quivalent  ce que ce que %S fait 
	automatiquement si quelqu'un essaie d'utiliser un nick
	protg par SET KILL.
	
	Quand vous utilisez cette commande, %S connectera un faux
	utilisateur avec le mme nick que l'utilisateur dont
	vous essayez de rcuprer le nick. Cela provoque la dconnexion
	par les serveurs IRC de l'autre utilisateur. Ce faux utilisateur
	restera connect pendant une minute pour s'assurer que l'autre
	utilisateur ne se reconnecte pas immdiatement; aprs cette
	minute, vous pouvez reprendre votre nick. Alternativement,
	utilisez la commande RELEASE (/msg %S HELP RELEASE) pour
	reprendre votre nick plus tt.
	
	Pour utiliser la commande RECOVER pour un nick, l'adresse
	telle qu'elle est montre dans un /WHOIS doit tre sur la
	liste d'accs du nick, ou vous devez fournir le mot de passe
	correct pour le nick.

NICK_HELP_RELEASE
	Syntaxe: RELEASE nick [motdepasse]
	
	Ordonne  %S de supprimer toute tutelle sur votre nick
	provoque par la protection de SET KILL ou 
	l'utilisation de la commande RECOVER. Par dfaut, les
	tutelles durent une minute; cette commande les
	arrte plus tt.
	
	Pour utiliser la commande RELEASE pour un nick, l'adresse
	telle qu'elle est montre dans un /WHOIS doit tre sur la
	liste d'accs du nick, ou vous devez fournir le mot de passe
	correct pour le nick.

NICK_HELP_GHOST
	Syntaxe: GHOST nick [motdepasse]
	
	Arrte une session IRC "fantme" utilisant votre nick. Une
	session "fantme" est un utilisateur non connect 
	actuellement, mais dont le serveur IRC croit qu'il l'est
	toujours pour une raison ou une autre. Habituellement,
	ceci arrive lorsque votre ordinateur plante ou que votre connexion
	 Internet s'arrte lorsque vous tes sur IRC.
	
	Pour utiliser la commande GHOST pour un nick, l'adresse
	telle qu'elle est montre dans un /WHOIS doit tre sur la
	liste d'accs du nick, ou vous devez fournir le mot de passe
	correct pour le nick.

NICK_HELP_INFO
	Syntaxe: INFO nick [ALL]
	
	Affiche des informations sur le nick donn, telles que
	le propritaire du nick, l'adresse avec laquelle il tait
	connect pour la dernire fois, et les options du nick. Si
	vous tes identifi pour le nick pour lequel vous demandez
	des informations et que ALL est spcifi, toutes
	les informations seront affiches, qu'elles soient caches
	ou non.

NICK_HELP_LIST
	Syntaxe: LIST modle
	
	Liste tous les nicks enregistrs qui correspondent
	au modle donn, dans le format nick!user@host. Les
	nicks avec l'option PRIVATE active ne seront pas
	affichs.
	
	Exemples:
	
	    LIST *!joeuser@foo.com
	        Liste tous les nicks appartenant  joeuser@foo.com.
	
	    LIST *Bot*!*@*
	        Liste tous les nicks enregistrs avec Bot dans leurs
	        noms (ne diffrencie pas minuscules et majuscules).
	
	    LIST *!*@*.bar.org
	        Liste tous les nicks appartenant aux utilisateurs dans le
	        domaine bar.org.

NICK_HELP_STATUS
	Syntaxe: STATUS nick...
	
	Retourne si l'utilisateur utilisant le nick donn est reconnu
	en tant que propritaire du nick. La rponse a ce format:
	
	    nick code-status
	
	o nick est le nick envoy avec la commande, et
	code-status peut tre l'un des suivants:
	
	    0 - cet utilisateur n'est pas online ou le nick n'est pas 
	        enregistr
	    1 - utilisateur non reconnu comme propritaire
	    2 - utilisateur reconnu comme propritaire uniquement via
	        la liste d'accs
	    3 - utilisateur reconnu comme propritaire via l'identification
	
	Jusqu' seize nicks peuvent tre envoys avec chaque commande;
	le reste sera ignor. Aucun message d'erreur n'est gnr si
	aucun nick n'est donn.

NICK_HELP_SENDPASS
	Syntaxe: SENDPASS nickname
	
	Envoie le mot de passe du nick donn  l'adresse e-mail 
	qui a t dfinie pour ce nick. Cette commande est trs
	utile pour rgler les problmes de mots de passe perdus.
	
	Peut tre limite aux IRC operators sur certains
	rseaux.
	
	Cette commande est indisponible quand l'encryption est
	active.

NICK_SERVADMIN_HELP
	
	Les commandes suivantes sont rserves aux Services admins:
	
	    GETPASS    Retrouve le mot de passe pour un nick
	                   (uniquement si l'encryption est dsactive)
	    FORBID     Empche l'utilisation d'un nick
	
	Les Services admins peuvent galement effacer n'importe quel
	nick sans avoir besoin de s'identifier pour le nick, et 
	peuvent voir l'access list pour n'importe kel nick 
	(/msg %S ACCESS LIST nick).

NICK_SERVADMIN_HELP_DROP
	Syntaxe: DROP [nick]
	
	Sans paramtre, efface votre nick de la base de donnes
	de %S.
	
	Avec un paramtre, efface le nick donn de la base de
	donnes. Cette utilisation est rserve aux Services admins.

NICK_SERVADMIN_HELP_SET
	
	Les Services admins peuvent galement dfinir l'option
	NOEXPIRE, qui empche les nicks d'expirer. De plus, 
	les Services admins peuvent dfinir les options de n'importe 
	quel nick sans avoir  entrer de mot de passe, en utilisant 
	le format SET nickname option paramtres.

NICK_SERVADMIN_HELP_SET_NOEXPIRE
	Syntaxe: SET [nick] NOEXPIRE {ON | OFF}
	
	Dfinit si le nick donn expirera. Activer ceci empchera
	le nick d'expirer. Si aucun nick n'est donn, dfinit 
	l'lment no-expire pour votre nick.
	
	Rserve aux Services admins.
	
NICK_SERVADMIN_HELP_UNLINK
	
	Les Services admins peuvent dlier tous les nicks sans 
	avoir  entrer de mot de passe.

NICK_SERVADMIN_HELP_LISTLINKS
	Syntaxe: LISTLINKS nick [ALL]
	
	Liste les nicks qui sont relis  un nick donn. Si ALL
	est spcifi, liste tous les nicks ayant les mme 
	privilges que le nick donn; sinon, liste seulement les
	nicks qui sont directement links sur le nick donn.
	
	Rserve aux Services admins.
	
NICK_SERVADMIN_HELP_INFO
	
	Les services admins peuvent utiliser le paramtre ALL 
	avec n'importe quel nick.

NICK_SERVADMIN_HELP_LIST
	Syntaxe: LIST modle [FORBIDDEN] [NOEXPIRE]
	
	Liste tous les nicks enregistrs qui correspondent au modle
	donn, de format nick!user@host. Les nicks ayant l'option
	PRIVATE ne seront affichs qu'aux Services admins. Les
	nicks ayant l'option NOEXPIRE seront prfixs par un !
	devant leur nick pour les Services admins. 
	
	Si les options FORBIDDEN ou NOEXPIRE sont donnes, seuls 
	les nicks qui, respectivement, sont interdits ou ont l'option
	NOEXPIRE active seront affiches. Si les deux options sont
	donnes, les deux types de nicks seront affichs. Ces options
	sont rserves aux Services admins.
	
	Exemples:
	
	    LIST *!joeuser@foo.com
	        Liste tous les nicks enregistrs appartenant  
	        joeuser@foo.com.
	
	    LIST *Bot*!*@*
	        Liste tous les nicks enregistrs ayant Bot dans
	        leur nom (ne respecte pas les majuscules).
	
	    LIST * NOEXPIRE
	        Liste tous les nicks qui n'expireront pas.

NICK_SERVADMIN_HELP_GETPASS
	Syntaxe: GETPASS nick
	
	Retourne le mot de passe du nick donn. Notez que pour
	chaque utilisation de cette commande, un message comprenant
	la personne qui a mis la commande et le nick sur lequel
	il a t utilis sera enregistr et envoy en WALLOPS/GLOBOPS.
	
	Rserve aux Services admins.
	
	Cette commande est indisponible quand l'encryption est active.

NICK_SERVADMIN_HELP_FORBID
	Syntaxe: FORBID nick [raison]
	
	Empche un nick d'tre enregistr ou utilis par 
	quelqu'un. Peut tre annul en effaant le nick.
	
	Sur certains rseaux, la raison est requise.
	
	Rserve aux Services admins.

###########################################################################
#
# ChanServ help messages
#
###########################################################################

CHAN_HELP
	%S vous permet d'enregistrer et de contrler divers
	aspects des channels. %S empche souvent de malicieux
	utilisateurs de faire des "take overs" sur les channels
	en limitant ceux qui sont autoriss  tre channel
	operator. Les commandes disponibles sont listes ci-dessous;
	pour les utiliser, tapez /msg %S command. Pour plus 
	d'informations sur une commande spcifique, tapez
	/msg %S HELP command.
	
	    REGISTER   Enregistre un channel
	    IDENTIFY   Vous identifie avec votre mot de passe
	    SET        Configure les options et informations du 
	               channel
	    ACCESS     Modifie la liste des utilisateurs privilgis
	    LEVELS     Redfinit la signification des levels d'accs
	    AKICK      Gre la liste des kicks automatiques
	    DROP       Annule l'enregistrement d'un channel
	
	Autres commandes: CLEAR, DEOP, DEVOICE, INFO, INVITE,
	                  LIST, OP, UNBAN, VOICE
	                  
CHAN_HELP_UNREAL
	
	Ces commandes sont galement disponibles sur ce rseau:
	    HALFOP, DEHALFOP, PROTECT, DEPROTECT

CHAN_HELP_EXPIRES
	Notez que tout channel non utilis pendant %d days
	(c'est--dire une priode pendant laquelle aucun
	utilisateur figurant sur la liste d'accs du channel
	ne vient sur le channel) sera automatiquement effac.

CHAN_HELP_REGISTER
	Syntaxe: REGISTER channel motdepasse description
	
	Enregistre un channel dans la base de donnes de %S. Pour
	utiliser cette commande, vous devez d'abord tre un
	oprateur sur le channel que vous essayez 
	d'enregistrer. Le mot de passe est utilis avec la commande
	IDENTIFY pour permettre  d'autres de faire des changements
	dans la configuration du channel plus tard. Le dernier
	paramtre, qui doit tre inclus, est une description
	gnrale du channel.
	
	Quand vous enregistrez un channel, vous tes enregistr
	comme "propritaire" du channel. Le propritaire du channel peut
	tout changer dans la configuration du channel; %S donnera
	aussi automatiquement au propritaire les droits d'oprateur
	du channel quand il ou elle joint le channel.
	Consultez la commande ACCESS (/msg %S HELP ACCESS) pour
	savoir comment donner un sous ensemble de ces droits 
	d'autres utilisateurs du channel.
	
	REMARQUE: Pour enregistrer un channel, vous devez
	d'abord enregistrer votre nick. Si ce n'est pas dj fait,
	tapez /msg %s HELP pour savoir comment faire.

CHAN_HELP_IDENTIFY
	Syntaxe: IDENTIFY channel motdepasse
	
	Certifie  %S que vous tes autoris  modifier le channel donn.
	Beaucoup de commandes demandent que vous utilisiez cette
	commande avant de les utiliser si vous n'tes pas le propritaire. 
	Le mot de passe est le mme que celui que vous avez envoy avec la
	commande REGISTER.

CHAN_HELP_DROP
	Syntaxe: DROP channel
	
	Efface le channel donn. Peut uniquement tre utilis par
	le propritaire du channel, qui doit utiliser la commande
	IDENTIFY d'abord.

CHAN_HELP_SET
	Syntaxe: SET channel option paramtres
	
	Permet au propritaire du channel de configurer diverses options
	du channel et d'autres informations.
	
	Options disponibles:
	
	    FOUNDER       Dfinit le propritaire d'un channel
	    SUCCESSOR     Dfinit le successeur d'un channel
	    PASSWORD      Dfinit le mot de passe du channel
	    DESC          Dfinit la description du channel
	    URL           Associe un site avec un channel
	    EMAIL         Associe un E-mail avec le channel
	    ENTRYMSG      Dfinit un message envoy aux utilisateurs
	                      qui entrent sur le channel
	    TOPIC         Change le topic du channel
	    BANTYPE       Dfinit comment les services mettent les bans
	                      sur le channel
	    KEEPTOPIC     Maintient le topic quand le channel n'est
	                      pas utilis
	    TOPICLOCK     Le topic peut uniquement tre chang avec
	                      SET TOPIC
	    MLOCK         Oblige ou interdit des modes de channel
	    PRIVATE       Cacher le channel de la commande LIST
	    RESTRICTED    Restreindre l'accs au channel
	    SECURE        Active les fonctions de scurit de %S
	    SECUREOPS     Contrle plus strict du status de chanop
	    SECUREFOUNDER Contrle plus strict du status de propritaire 
	                      du channel
	    LEAVEOPS      Ne jamais deop les utilisateurs sauf avec la
	                      commande DEOP
	    OPNOTICE      Envoie une notice quand OP/DEOP sont utiliss.
	
	Tapez /msg %S HELP SET option pour plus d'informations sur
	une option particulire.

CHAN_HELP_SET_FOUNDER
	Syntaxe: SET channel FOUNDER nick
	
	Change le propritaire d'un channel. Le nouveau nick doit tre
	enregistr.

CHAN_HELP_SET_SUCCESSOR
	Syntaxe: SET channel SUCCESSOR nick
	
	Change le successeur d'un channel. Si le nick du propritaire
	expire ou est effac alors que le channel est toujours
	enregistr, le successeur deviendra le nouveau propritaire du
	channel. Cependant, si le successeur a dj trop de channels
	enregistrs (%d), le channel sera tout de mme effac, comme
	si aucun successeur n'avait t nomm. Le nouveau nick
	doit tre enregistr.

CHAN_HELP_SET_PASSWORD
	Syntaxe: SET channel PASSWORD motdepasse
	
	Dfinit le mot de passe utilis pour s'identifier en tant
	que propritaire du channel.

CHAN_HELP_SET_DESC
	Syntaxe: SET channel DESC description
	
	Dfinit la description du channel, qui apparait dans les
	commandes LIST et INFO.

CHAN_HELP_SET_URL
	Syntaxe: SET channel URL [adresse]
	
	Associe l'adresse de site web donne avec le channel. Cette adresse 
	sera affiche  chaque fois que quelqu'un demande des informations
	sur le channel avec la commande INFO. Si aucun paramtre
	n'est donn, supprime l'adresse de site du channel.

CHAN_HELP_SET_EMAIL
	Syntaxe: SET channel EMAIL [adresse]
	
	Associe l'e-mail donn avec le channel. Cet
	e-mail sera affich lorsque quelqu'un demande des informations
	sur le channel avec la commande INFO. Si aucun paramtre
	n'est donn, supprime l'e-mail actuel du channel.

CHAN_HELP_SET_ENTRYMSG
	Syntaxe: SET channel ENTRYMSG [message]
	
	Dfinit le message qui sera envoy en /notice aux 
	utilisateurs quand ils entrent dans un channel. Si aucun
	paramtre n'est donn, aucun message n'est envoy 
	l'entre.

CHAN_HELP_SET_TOPIC
	Syntaxe: SET channel TOPIC topic
	
	Demande  %S de changer le topic du channel pour
	celui spcifi. Cette commande est plus utile en
	conjonction avec SET TOPICLOCK.
	
CHAN_HELP_SET_BANTYPE
	Syntaxe: SET channel BANTYPE typedeban
	
	Dfinit le type de ban qui sera utilis par les services
	lorsqu'ils doivent bannir quelqu'un de votre channel.
	
	typedeban est un nombre entre 0 et 3 qui signifie:
	
	0: ban de style *!user@host
	1: ban de style *!*user@host
	2: ban de style *!*@host
	3: ban de style *!*user@*.domain

CHAN_HELP_SET_KEEPTOPIC
	Syntaxe: SET channel KEEPTOPIC {ON | OFF}
	
	Active ou dsactive l'option de maintien du topic pour
	un channel. Lorsque le maintien du topic est dfini, le 
	topic pour le channel sera retenu par %S mme aprs que le
	dernier utilisateur quitte le channel, et sera restaur la
	prochaine fois que le channel est cr. 

CHAN_HELP_SET_TOPICLOCK
	Syntaxe: SET channel TOPICLOCK {ON | OFF}
	
	Active ou dsactive l'option de verrouillage du topic pour
	un channel. Lorsque le verrouillage du topic est actif,
	%S ne permettra pas le changement du topic du channel sauf
	avec la commande SET TOPIC.

CHAN_HELP_SET_MLOCK
	Syntaxe: SET channel MLOCK modes
	
	Configure les modes bloqus sur le channel. %S
	vous permet d'enforcer les modes (ou de les dsactiver). Les modes
	qui peuvent tre bloqus sont i, k, l, m, n, p, s, et 
	t (d'autres peuvent tre dfinis sur certains rseaux); chacun de 
	ces modes peuvent tre enforcs, dsactivs, ou
	non bloqus. Le paramtre modes est construit de la mme faon
	que dans la commande /MODE; donc, les modes prcds d'un + sont
	enforcs, et les modes prcds d'un - dsactivs. 
	
	Attention: Si vous enforcez le mode +k, comme dans le second
	exemple ci-dessous, vous devriez aussi dfinir l'option
	RESTRICTED pour le channel (consultez HELP SET RESTRICTED),
	sinon toute personne entrant sur le channel lorsqu'il est vide
	pourra voir la clef!  
	
	Exemples:
	
	    SET #channel MLOCK +nt-iklps
		  Enforce les modes n et t, et dsactive les modes i,
		  k, l, p, et s. Le mode m est libre d'etre mis ou
		  enlev.
	
	    SET #channel MLOCK +knst-ilmp ma-clef
	        Enforce les modes k, n, s, et t, et dsactive les
		  modes i, l, m, et p. Force aussi la clef du channel
		   tre "ma-clef".
	
	    SET #channel MLOCK +
	        Removes the mode lock; all channel modes are free
	        to be either on or off.

CHAN_HELP_SET_PRIVATE
	Syntaxe: SET channel PRIVATE {ON | OFF}
	
	Active ou dsactive l'option private pour un channel.
	Si private est dfini, un /msg %S LIST ne comprendra
	le channel dans aucune liste.

CHAN_HELP_SET_RESTRICTED
	Syntaxe: SET channel RESTRICTED {ON | OFF}
	
	Active ou dsactive l'option d'accs restreint pour un
	channel. Lorsque l'accs restreint est actif, les
	utilisateurs qui n'auraient normalement pas la permission
	d'tre channel operator (les utilisateurs avec un niveau
	d'accs ngatif et, si le contrle des ops est actif, les utilisateurs
	qui ne sont pas sur la liste d'accs) seront kicks et bannis
	du channel.

CHAN_HELP_SET_SECURE
	Syntaxe: SET channel SECURE {ON | OFF}
	
	Active ou dsactive les caractristiques de scurit
	pour un channel. Lorsque la scurit est active, seuls les
	utilisateurs qui ont enregistr leurs nicks avec %s et
	qui sont identifis avec leur mot de passe auront accs
	au channel sous contrle de la liste d'accs.

CHAN_HELP_SET_SECUREOPS
	Syntaxe: SET channel SECUREOPS {ON | OFF}
	
	Active ou dsactive le contrle des ops sur un channel.
	Lorsque le contrle des ops est actif, les utilisateurs 
	qui ne sont pas sur la liste d'accs ne pourront tre op.
	
CHAN_HELP_SET_SECUREFOUNDER
	Syntaxe: SET channel SECUREFOUNDER {ON | OFF}
	
	Active ou dsactive l'option contrle du propritaire pour un channel.
	Lorsque le contrle du propritaire est activ, seul le vrai 
	propritaire pourra effacer le channel, changer son mot de passe, 
	son propritaire et son successeur, et non pas ceux qui sont identifis 
	avec %S. 

CHAN_HELP_SET_LEAVEOPS
	Syntaxe: SET channel LEAVEOPS {ON | OFF}
	
	Active ou dsactive l'option deop strict d'un channel.
	Lorsque le deop strict est actif, ChanServ ne deoppera jamais
	un utilisateur de ce channel sauf avec la commande DEOP.

CHAN_HELP_SET_OPNOTICE
	Syntaxe: SET channel OPNOTICE {ON | OFF}
	
	Active ou dsactive l'option notice sur OP/DEOP pour un channel.
	Lorsque notice sur OP/DEOP est dfini, ChanServ enverra un notice au
	channel  chaque fois que les commandes OP ou DEOP sont
	utilises par un utilisateur sur le channel.

CHAN_HELP_ACCESS
	Syntaxe: ACCESS channel ADD nick level
	         ACCESS channel DEL {nick | numros d'entre | liste}
	         ACCESS channel LIST [mask | liste]
	         ACCESS channel CLEAR
	
	Gre la liste d'accs d'un channel. La liste d'accs
	dtermine quels utilisateurs ont le status d'oprateur ou
	ont accs aux commandes de %S pour le channel. Diffrents
	levels utilisateur donnent accs  diffrents lots de 
	privilges; /msg %S HELP ACCESS LEVELS pour des informations
	plus dtailles. Tout nick qui n'est pas sur la liste
	d'accs a un level utilisateur de 0.
	
	La commande ACCESS ADD ajoute le nick donn  la liste
	d'accs avec le level utilisateur choisi; si le nick est
	dj prsent dans la liste, son niveau d'accs est remplac
	par le level spcifi dans la commande. Le level spcifi
	doit tre infrieur que celui qui utilise la commande, et
	si le nick est dj dans la liste d'accs, le level
	d'accs actuel de ce nick doit tre infrieur  celui de
	la personne utilisant la commande.
	
	La commande ACCESS DEL supprime le nick donn de
	la liste d'accs. Si une liste de numros d'entres est 
	donne, ces entres sont supprimes. (Consultez l'exemple
	pour LIST ci-dessous.)
	
	La commande ACCESS LIST affiche la liste d'accs. Si un
	mask joker est donn, seules les entres correspondantes
	au mask sont affiches. Si une liste de numros d'entre
	est donne, seules ces entres sont affiches; par exemple:

	   ACCESS #channel LIST 2-5,7-9
	        Liste toutes les entres comprises entre 2 et 5 et
	        entre 7 et 9.
	
	La commande ACCESS CLEAR supprime toutes les entres
	de la liste d'accs.

CHAN_HELP_ACCESS_LEVELS
	Levels d'accs utilisateur
	
	Par dfaut, les levels d'accs suivants sont dfinis:
	
	   Proprio   Plein accs aux fonctions de %S; Op 
	               automatique ds l'entre sur le channel.
	               Notez que seule une personne peut
	               avoir le status de propritaire (il ne peut
	               tre donn en utilisant la commande
	               ACCESS).
	        10   Accs  la commande AKICK; Op automatique.
	         5   Op automatique.
	         3   Voice automatique.
	         0   Aucun privilge particulier.
	        <0   Ne doit pas tre op.
	
	Ces levels peuvent tre changs, ou de nouveaux ajouts,
	en utilisant la commande LEVELS; tapez /msg %S HELP LEVELS
	pour plus d'informations.

CHAN_HELP_AKICK
	Syntaxe: AKICK channel ADD mask [raison]
	         AKICK channel DEL mask
	         AKICK channel LIST [mask]
	         AKICK channel VIEW [mask]
	         AKICK channel ENFORCE
	         AKICK channel CLEAR
	
	Gre la liste de kicks automatiques d'un channel. Si 
	un utilisateur figurant sur la liste de kicks automatiques tente 
	de joindre un channel, %S bannira cet utilisateur du channel, et 
	kickera ensuite l'utilisateur.
	
	La commande AKICK ADD ajoute le nick donn ou le
	mask d'utilisateur  la liste de kicks automatiques. Si une 
	raison est donne avec la commande, cette raison sera utilise 
	lorsque l'utilisateur est kick; sinon, la raison par dfaut est
	"You have been banned from the channel". 
	
	La commande AKICK DEL supprime le nick ou le masque donn
	de la liste de kicks automatiques. Cependant, il n'enlve pas 
	les bans placs par une des entres; ceux-l doivent tre supprims
	manuellement.
	
	La commande AKICK LIST affiche la liste de kicks 
	automatiques, ou optionnellement seulement les entres de la liste 
	de kicks automatiques qui correspondent au mask donn.
	
	La commande AKICK VIEW est une version plus dtaille de
	la commande AKICK LIST.
	
	La commande AKICK ENFORCE force %S  bannir tous les
	utilisateurs prsents sur le channel qui sont concerns 
	par une des entres de la liste de kicks automatiques.
	
	La commande AKICK CLEAR supprime toutes les entres
	de la liste de kicks automatiques.

CHAN_HELP_LEVELS
	Syntaxe: LEVELS channel SET type level
	         LEVELS channel {DIS | DISABLE} type
	         LEVELS channel LIST
	         LEVELS channel RESET
	
	La commande LEVELS permet un contrle prcis de la 
	signification des levels d'accs utiliss pour les channels.
	Avec cette commande, vous pouvez dfinir le level d'accs
	requis pour la majorit des fonctions de %S. (Les commandes
	SET FOUNDER et SET PASSWORD, ainsi que cette commande,
	sont toujours rserves au propritaire du channel.)
	
	LEVELS SET permet au level d'accs pour une fonction ou un
	groupe de fonctions d'tre chang. LEVELS DISABLE (ou DIS
	en abrg) dsactive une fonction automatique ou empche l'accs
	 une fonction par quiconque sauf le propritaire du channel.
	LEVELS LIST montre les levels courants pour chaque fonction
	ou groupe de fonctions. LEVELS RESET rinitialise les levels
	avec les levels par dfaut d'un channel fraichement cr 
	(consultez HELP ACCESS LEVELS).

	Pour une liste de caractristiques et fonctions pour lesquels
	des levels peuvent tre dfinis, consultez HELP LEVELS DESC.

CHAN_HELP_LEVELS_DESC
	Les noms de caractristiques/fonctions suivants sont utiliss.
	Notez que les levels pour AUTODEOP et NOJOIN sont des levels
	maximum, alors que tous les autres sont des levels minimum.

CHAN_HELP_LEVELS_DESC_FORMAT
	    %-*s  %s

CHAN_HELP_INFO
	Syntaxe: INFO channel [ALL]
	
	Liste les informations concernant le channel nomm
	enregistr, dont son propritaire, la date d'enregistrement,
	la date de dernire utilisation, la description, et
	les modes bloqus, si il y en a. Si vous tes identifi
	pour le channel pour lequel vous demandez des informations
	et que ALL est donn, le message d'entre et successeur
	seront galement affichs.

CHAN_HELP_LIST
	Syntaxe: LIST modle
	
	Liste tous les channels enregistrs correspondants au
	modle donn. (Les channels avec l'option PRIVATE ne
	sont pas lists.)

CHAN_HELP_OP
	Syntaxe: OP [#channel [nick]]
	
	Op le nick slectionn sur un channel. Si nick n'est pas
	donn, %S vous oppera sur le channel donn. Si nick et
	channel ne sont pas donns, %S vous oppera sur tous
	les channels o vous tes.
	
	Par dfaut, limit  ceux ayant au moins un level d'accs 
	de 5 ou plus sur le channel.

CHAN_HELP_DEOP
	Syntaxe: DEOP [#channel [nick]]
	
	Deop le nick slectionn sur un channel. Si nick n'est pas
	donn, %S vous deoppera sur le channel donn. Si nick et
	channel ne sont pas donns, %S vous deoppera sur tous
	les channels o vous tes.

	Par dfaut, limit  ceux ayant au moins un level d'accs 
	de 5 ou plus sur le channel.
	
CHAN_HELP_VOICE
	Syntaxe: VOICE [#channel [nick]]
	
	Voice le nick slectionn sur un channel. Si nick n'est pas
	donn, %S vous voicera sur le channel donn. Si nick et
	channel ne sont pas donns, %S vous voicera sur tous
	les channels o vous tes.
	
	Par dfaut, limit  ceux ayant au moins un level d'accs 
	de 5 ou plus sur le channel, ou  ceux ayant au moins un
	level d'accs de 3 en cas de voice de soi meme.

CHAN_HELP_DEVOICE
	Syntaxe: DEVOICE [#channel [nick]]
	
	Devoice le nick slectionn sur un channel. Si nick n'est pas
	donn, %S vous devoicera sur le channel donn. Si nick et
	channel ne sont pas donns, %S vous devoicera sur tous
	les channels o vous tes.

	Par dfaut, limit  ceux ayant au moins un level d'accs 
	de 5 ou plus sur le channel, ou  ceux ayant au moins un
	level d'accs de 3 en cas de voice de soi meme.
	
CHAN_HELP_HALFOP
	Syntaxe: HALFOP [#channel [nick]]
	
	Halfop le nick slectionn sur un channel. Si nick n'est pas
	donn, %S vous halfoppera sur le channel donn. Si nick et
	channel ne sont pas donns, %S vous halfoppera sur tous
	les channels o vous tes.
	
	Par dfaut, limit  ceux ayant au moins un level d'accs 
	de 5 ou plus sur le channel, ou  ceux ayant au moins un
	level d'accs de 4 en cas de halfop de soi meme.

CHAN_HELP_DEHALFOP
	Syntaxe: DEHALFOP [#channel [nick]]
	
	Dehalfop le nick slectionn sur un channel. Si nick n'est pas
	donn, %S vous dehalfoppera sur le channel donn. Si nick et
	channel ne sont pas donns, %S vous dehalfoppera sur tous
	les channels o vous tes.

	Par dfaut, limit  ceux ayant au moins un level d'accs 
	de 5 ou plus sur le channel, ou  ceux ayant au moins un
	level d'accs de 4 en cas de voice de soi meme.
	
CHAN_HELP_PROTECT
	Syntaxe: PROTECT [#channel [nick]]
	
	Protge le nick slectionn sur un channel. Si nick n'est pas
	donn, %S vous protgera sur le channel donn. Si nick et
	channel ne sont pas donns, %S vous protgera sur tous
	les channels o vous tes.
	
	Par dfaut, reserv au founder, ou  ceux ayant au moins un
	level d'accs de 10 en cas de protection de soi meme.

CHAN_HELP_DEPROTECT
	Syntaxe: DEPROTECT [#channel [nick]]
	
	Dprotge le nick slectionn sur un channel. Si nick n'est pas
	donn, %S vous dprotgera sur le channel donn. Si nick et
	channel ne sont pas donns, %S vous dprotgera sur tous
	les channels o vous tes.

	Par dfaut, limit  ceux ayant au moins un level d'accs 
	de 5 ou plus sur le channel, ou  ceux ayant au moins un
	level d'accs de 4 en cas de voice de soi meme.

CHAN_HELP_INVITE
	Syntaxe: INVITE channel
	
	Demande  %S de vous inviter sur le channel donn. Par dfaut, 
	limit  ceux ayant au moins un level d'accs de 5 ou plus sur
	le channel.


CHAN_HELP_UNBAN
	Syntaxe: UNBAN channel
	
	Demande  %S d'enlever tous les bans vous empchant
	d'entrer sur le channel donn. Par dfaut, limit
	 ceux ayant au moins un level d'accs de 5 ou plus sur
	le channel.


CHAN_HELP_CLEAR
	Syntaxe: CLEAR channel quoi
	
	Demande  %S d'enlever certains aspects d'un channel. 
	what peut tre un des suivants:
	
	     MODES   Rinitialise tous les modes d'un channel
	     BANS    Enlve tous les bans d'un channel.
	     OPS     Enlve le status de channel operator 
	             tous les channel operators du channel.
	     VOICES  Enlve le status de "voice" (mode +v)  toute
	             personne ayant ce mode.
	     USERS   Kicke tous les utilisateurs d'un channel.
	
	Par dfaut, votre level d'accs sur le channel doit tre
	d'au moins 10 pour utiliser cette commande.
	
CHAN_HELP_GETKEY
	Syntaxe: GETKEY channel
	
	Retourne la clef du channel donn. GETKEY est une commande
	qui est principalement destin  tre utilise par des
	bots ou des scripts; pour cela, la rponse a le format
	suivant:
	
	KEY <channel> <clef>
	
	La clef sera "NO KEY" si aucune clef n'est dfinie.
	
CHAN_HELP_SENDPASS
	Syntaxe: SENDPASS channel
	
	Envoie le mot de passe du channel donn  l'adresse e-mail 
	qui a t dfinie pour le propritaire de ce channel. Cette 
	commande est trs utile pour rgler les problmes de mots 
	de passe perdus.
	
	Peut tre limite aux IRC operators sur certains
	rseaux.
	
	Cette commande est indisponible quand l'encryption est
	active.

CHAN_SERVADMIN_HELP
	
	Les commandes suivantes sont disponibles pour les Services
	admins:
	
	    GETPASS    Retrouve le mot de passe du propritaire pour
	               un channel (seulement si l'encryption 
	               est dsactive)
	    FORBID     Empche un channel d'tre utilis
	    STATUS     Retourne le level d'accs courant d'un
	                utilisateur sur un channel
	
	Les Services admins peuvent aussi effacer tout channel sans
	avoir besoin de s'identifier avec un mot de pass, et peuvent
	voir l'access, AKICK, et level lists de tout channel.

CHAN_SERVADMIN_HELP_DROP
	Syntaxe: DROP channel
	
	Efface le channel nomm. Seuls les Services admins
	peuvent effacer un channel pour lequel ils n'ont
	pas t identifis.

CHAN_SERVADMIN_HELP_SET
	
	Les Services admins peuvent aussi dfinir l'option 
	NOEXPIRE, avec lequel les channels peuvent tre empchs
	d'expirer. De plus, les Services admins peuvent dfinir
	les options de tout channel sans s'identifier avec le
	password d'un channel. 

CHAN_SERVADMIN_HELP_SET_NOEXPIRE
	Syntaxe: SET channel NOEXPIRE {ON | OFF}
	
	Dfinit si le channel donn expirera. Mettre ceci  ON
	empche le channel d'expirer.
	
	Rserve aux Services admins.

CHAN_SERVADMIN_HELP_INFO
	
	Les services admins peuvent utiliser le paramtre ALL 
	avec n'importe quel channel.

CHAN_SERVADMIN_HELP_LIST
	Syntaxe: LIST modle
	
	Liste tous les channels enregistrs correspondants au modle
	donn. Les channels avec l'option PRIVATE seront uniquement
	affichs aux Services admins. Les channels ayant l'option 
	NOEXPIRE seront prfixs par un ! pour les Services admins. 
	
	Si les options FORBIDDEN ou NOEXPIRE sont donnes, seuls 
	les channels qui, respectivement, sont interdits ou ont l'option
	NOEXPIRE active seront affichs. Si les deux options sont
	donnes, les deux types de channels seront affichs. Ces options
	sont rserves aux Services admins.

CHAN_SERVADMIN_HELP_GETPASS
	Syntaxe: GETPASS channel
	
	Retourne le mot de passe du channel donn. Notez que
	lorsque cette commande est utilise, un message comprenant
	la personne qui a utilis cette commande et le channel
	pour lequel elle a t utilise sera logge et envoye en
	un WALLOPS/GLOBOPS.
	
	Rserve aux Services admins.

CHAN_SERVADMIN_HELP_FORBID
	Syntaxe: FORBID channel [raison]
	
	Empche toute personne d'enregistrer ou d'utiliser le
	channel donn. Peut tre annul en effacant le channel.
	
	La raison peut tre requise sur certains rseaux.
	
	Rserve aux Services admins.

CHAN_SERVADMIN_HELP_STATUS
	Syntaxe: STATUS channel nick
	
	Retourne le level d'accs actuel du nick donn pour le 
	channel donn. La rponse est de la forme:
	
	    STATUS channel nickname access-level
	
	Si une erreur se produit, la rponse sera de la forme:
	
	    STATUS ERROR error-message
	
	Rserve aux Services admins.

###########################################################################
#
# MemoServ help messages
#
###########################################################################

MEMO_HELP
	%S est un utilitaire permettant aux utilisateurs IRC
	d'envoyer de courts messages aux autres utilisateurs IRC,
	qu'ils soient online  ce moment l ou non, ou aux 
	channels(*). Le nick de l'expditeur ET du destinataire ou
	le channel doivent tre enregistrs pour pouvoir envoyer un
	memo.
	
	Les commandes de %S sont:
	
	    SEND   Envoie un memo  un nick ou un channel
	    CANCEL Annule le dernier memo que vous avez envoy
	    LIST   Liste vos memos
	    READ   Lit un ou des memos
	    DEL    Efface un ou des memos
	    SET    Dfinit des options relatifs aux memos
	
	Tapez /msg %S HELP commande pour de l'aide sur
	une des commandes ci-dessus.
	
	(*) Par dfaut, tout utilisateur avec au moins un level d'accs
	    de 10 sur un channel peut lire ces memos du channel. Ceci
	    peut tre chang avec la commande LEVELS de %s.

MEMO_HELP_SEND
	Syntaxe: SEND {nick | channel} texte du memo
	
	Envoie un memo au nick ou channel nomm contenant
	texte du memo. En envoyant  un nick, le destinataire
	sera inform qu'il/elle a un nouveau memo. Le nick/channel
	destinataire doit tre enregistr.
	
MEMO_HELP_CANCEL
	Syntaxe: CANCEL {nick | channel}
	
	Supprime le dernier memo que vous avez envoy  un nick ou
	channel donn,  condition qu'il n'ait pas t lu lorsque vous
	utilisez la commande.

MEMO_HELP_LIST
	Syntaxe: LIST [channel] [liste | NEW]
	
	Liste tous les memos que vous avez actuellement. Avec NEW,
	liste uniquement les nouveaux memos (non lus). Les memos non
	lus sont marqus avec un "*"  gauche du numro du memo. Vous
	pouvez galement spcifier une liste de numros, comme dans
	l'exemple ci dessous:

	   LIST 2-5,7-9
	      Liste les memos 2  5 et 7  9.

MEMO_HELP_READ
	Syntaxe: READ [channel] {nombre | liste | LAST | NEW}
	
	Vous envoie le texte des memos spcifis. Si LAST est donn,
	vous envoie le dernier memo reu. Si NEW est donn, vous
	envoie tous vos nouveaux memos. Sinon, vous envoie le memo
	numro nombre. Vous pouvez galement donner une liste
	de nombres, comme dans cet exemple:
	
	   READ 2-5,7-9
	      Affiche les memos 2  5 et 7  9.

MEMO_HELP_DEL
	Syntaxe: DEL [channel] {nombre | liste | ALL}
	
	Deletes the specified memo or memos.  You can supply
	multiple memo numbers or ranges of numbers instead of a
	single number, as in the second example below.
	Supprime le ou les memos spcifis. Vous pouvez
	fournir plusieurs numros de memos ou des ordres de nombres
	au lieu d'un nombre unique, comme dans le second exemple
	ci-dessous.
	
	Si ALL est donn, supprime tous vos memos.
	
	Exemples:
	
	   DEL 1
	      Supprime votre premier memo.
	
	   DEL 2-5,7-9
	      Supprime les memos compris entre 2 et 5 et entre 7 et 9.

MEMO_HELP_SET
	Syntaxe: SET option paramtres
	
	Dfinit plusieurs options de memo. option peut tre:
	
	    NOTIFY      Dfinit si vous serez notifis de vos
	                  nouveaux memos (seulement pour les 
	                  nicks)
	    LIMIT       Dfinit le nombre de memos maximum que 
	                  vous pouvez recevoir
	
	Tapez /msg %S HELP SET option pour plus 
	d'informations sur une option spcifique.

MEMO_HELP_SET_NOTIFY
	Syntaxe: SET NOTIFY {ON | LOGON | NEW | OFF}
	
	Change quand vous serez notifi de vos nouveaux
	memos:
	
	    ON     Vous serez notifis lorsque vous vous connectez,
	           lorsque vous enlevez /AWAY, et quand ils vous
	           sont envoys.	
	    LOGON  Vous serez uniquement notifis des memos lorsque
	           vous vous connectez ou quand vous enlevez
	           /AWAY.
	    NEW    Vous serez uniquement notifis des memos 
	           lorsqu'ils vous sont envoys.
	    OFF    Vous ne recevrez aucune notification.
	
	ON est la combination de LOGON et NEW.

MEMO_HELP_SET_LIMIT
	Syntaxe: SET LIMIT [channel] limite
	
	Dfinit le nombre maximum de memos que vous (ou le channel
	donn) est autoris  avoir. Si vous dfinissez ceci  0,
	personne ne pourra vous envoyer de memos. Cependant, vous
	ne pouvez pas dfinir ceci  plus que %d.

MEMO_HELP_INFO
	Syntaxe: INFO [channel]
	
	Affiche des informations sur le nombre de memos que vous
	avez, combien sont non lus, et combien de memos vous pouvez
	recevoir au total. Avec un paramtre, affiche la mme
	information pour le channel donn.

MEMO_SERVADMIN_HELP_SET_LIMIT
	Syntaxe: SET LIMIT [utilisateur | channel] {limite | NONE} [HARD]
	
	Dfinit le nombre maximum de memos qu'un utilisateur ou
	un channel est autoris  avoir. Dfinir la limite  0
	empche l'utilisateur de recevoir des memos; dfinir ceci
	 NONE permet  l'utilisateur de recevoir et garder
	autant de memos qu'ils veulent. Si vous ne donnez pas de
	nick ou de channel, votre propre limite est dfinie.
	
	Ajouter HARD empche l'utilisateur de changer cette limite.
	Ne pas ajouter HARD a l'effet inverse, permettant  
	l'utilisateur de changer cette limite (mme si une limite
	antrieure a t dfinie avec HARD).
	
	Cette utilisation de la commande SET LIMIT est rserve aux
	Services admins. Les autres utilisateurs peuvent uniquement
	entrer une limite pour eux-mmes ou un channel sur lequel ils
	ont de tels privilges, ne peuvent supprimer leur limite, et
	ne peuvent dfinir de limite stricte.

MEMO_SERVADMIN_HELP_INFO
	Syntaxe: INFO [nick | channel]
	
	Sans paramtre, affiche les informations sur le nombre
	de memos que vous avez, combien sont non lus, et combien
	de memos vous pouvez recevoir au total.
	
	Avec un paramtre de channel, affiche la mme information
	pour le channel donn.
	
	With a nickname parameter, displays the same information
	for the given nickname.  This use Rserve aux Services
	admins.
	Avec un paramtre de nick, affiche la mme information 
	pour le nick donn. Cette utilisation rserve aux Services
	admins.

###########################################################################
#
# OperServ help messages
#
###########################################################################

OPER_HELP
	Commandes %S:
	    GLOBAL      Envoie un message  tous les utilisateurs
	    STATS       Affiche le status des Services et du rseau
	    OPER LIST   Liste tous les Services operators
	    ADMIN LIST  Liste tous les Services admins
	
	Commandes rserves aux Services admins et Services operators:
	    MODE        Change les modes d'un channel
	    KICK        Kick un utilisateur d'un channel
	    AKILL       Contrle l'AKILL list
	
	Commandes rserves aux Services admins:
	    SESSION     Affiche la liste des sessions par host
	    EXCEPTION   Modifie la liste d'exception  la limite de
	                    session.
	    KILLCLONES  Dconnecte tous les utilisateurs ayant une
	                    certaine host.
	    CHANLIST    Liste tous les channels
	    USERLIST    Liste tous les utilisateurs
	    OPER        Modifie la Services operator list
	    LOGONNEWS   Dfinit les messages affichs aux utilisateurs
	                     la connexion.
	    OPERNEWS    Dfinit les messages affichs aux utilisateurs
	                    qui deviennent IRCops.
	    JUPE        "Jupiter" un serveur
	    RAW         Envoie une chane brute au server IRC
	    SET         Configure des options globales aux services
	    UPDATE      Oblige les bases de donnes des Services
	                     tre mises  jour sur le disque immdiatement.
	    QUIT        Arrte le programme des Services
	    RESTART     Sauvegarde les bases de donnes et relance les
	                    Services.
	
	Commandes rserves au Services root:
	    ADMIN       Modifie la Services admin list
	
	Remarque: Toutes les commandes envoyes  %S sont enregistres!

OPER_HELP_GLOBAL
	Syntaxe: GLOBAL message
	
	Permet aux IRCops d'envoyer des messages  tous les 
	utilisateurs du rseau. Le message sera envoy avec
	le nick %s.

OPER_HELP_STATS
	Syntaxe: STATS [AKILL | ALL]
	
	Sans option, affiche le nombre d'utilisateurs et d'IRCops
	actuellement online (Services exclus), le plus grand nombre
	d'utilisateurs online depuis le dmarrage des Services, et
	le nombre d'heures durant lesquelles les Services ont tourn.
	
	Avec l'option AKILL, affiche la taille actuelle de l'AKILL
	list et le temps d'chance par dfaut.
	
	L'option ALL est rserve uniquement aux Services admins,
	et affiche des informations sur l'utilisation de la mmoire
	par les Services. L'utilisation de cette commande peut geler
	les Services pendant un court instant sur de grands rseaux,
	donc n'en abusez pas!
	
	L'option RESET rinitialise le nombre maximum d'utilisateurs
	au nombre courant d'utilisateurs sur le rseau.
	
	UPTIME est l'quivalent de STATS.

OPER_HELP_OPER
	Syntaxe: OPER ADD nick
	         OPER DEL nick
	         OPER LIST
	
	Permet aux Services admins d'ajouter ou de supprimer des
	nicks  ou de la Services operator list. Un utilisateur dont
	le nick est dans la Services operator list et qui est 
	identifi auprs de %s aura accs aux commandes de Services
	operator.
	
	Un IRC operator peut utiliser la forme OPER LIST de la commande.
	Toutes autres utilisations rserves aux Services admins.

OPER_HELP_ADMIN
	Syntaxe: ADMIN ADD nick
	         ADMIN DEL nick
	         ADMIN LIST
	
	Permet au Services root d'ajouter ou de supprimer des
	nicks  ou de la Services admin list. Un utilisateur dont
	le nick est dans la Services admin list et qui est 
	identifi auprs de %s aura accs aux commandes de Services
	admin.
	
	Un IRC operator peut utiliser la forme ADMIN LIST de la commande.
	Toutes autres utilisations rserves au Services root.

OPER_HELP_MODE
	Syntaxe: MODE channel modes
	
	Permet aux Services operators de dfinir les modes d'un
	channel. Les paramtres sont les mmes que pour la commande
	/MODE normale.
	
	Rserve aux Services operators.

OPER_HELP_CLEARMODES
	Syntaxe: CLEARMODES channel [ALL]
	
	Enlve tous les modes binaires (i,k,l,m,n,p,s,t) et les bans
	d'un channel. Si ALL est donn, enlve galement tous les
	ops et voices (modes +o et +v) du channel.
	
	Rserve aux Services operators.

OPER_HELP_KICK
	Syntaxe: KICK channel utilisateur raison
	
	Permet aux IRCops de kicker un utilisateur d'un channel.
	Les paramtres sont les mmes que pour la commande /KICK
	normale. Le message de kick sera prfix du nick de
	l'IRCop ayant utilis la commande KICK; par exemple:
	
	*** SpamMan has been kicked off channel #my_channel by %S (Alcan (Flood))
	
	Rserve aux Services operators.

OPER_HELP_AKILL
	Syntaxe: AKILL ADD [+chance] mask raison
	         AKILL DEL mask
	         AKILL LIST [mask]
	         AKILL VIEW [mask]
	
	Permet aux Services operators de manipuler l'AKILL list. Si
	un utilisateur correspondant  un mask de l'AKILL tente de
	se connecter, les Services procderont  un KILL sur cet
	utilisateur et, sur les types de serveur le supportant, 
	ordonnera  tous les serveurs d'ajouter un ban (K-line) pour
	le mask correspondant  l'utilisateur.
	
	AKILL ADD ajoute le mask user@host donn  l'AKILL list
	pour la raison donne (qui doit tre donne).
	AKILL DEL supprime le mask donn de l'AKILL list si il
	existe. AKILL LIST affiche les AKILLs actuelles; si le
	mask optionnel est donn, la liste se limite aux AKILLs
	correspondant au mask. AKILL VIEW est une version plus
	dtaille de AKILL LIST, et affichera qui a ajout une
	AKILL, la date  laquelle elle a t ajoute, et kd elle
	expire, ainsi que le mask user@host et la raison.
	
	Optionellement, une date d'chance peut tre donne avec la
	commande AKILL ADD. La date d'chance prcde le mask
	user@host, et est compose d'un nombre entier suivi par un
	d (jours), h (heures), ou m (minutes). Les combinaisons
	(de type 1h30m) ne sont pas permises. Si aucune unit n'est
	spcifie, l'unit par dfaut (jours) sera employe (ainsi
	+30 signifie implicitement 30 jours). Pour ajouter une
	AKILL ki n'expire pas, utilisez +0. Si le usermask  ajouter
	commence par un +, une date d'chance doit tre donne, mme
	si c'est la mme que celle par dfaut. La date d'chance par
	dfaut pour l'AKILL peut tre trouve avec la commande STATS 
	AKILL.
	
	La raison est destine  l'utilisation par les IRC operators
	uniquement, et ne sera pas affiche aux utilisateurs dans les
	messages KILL.
	
	Rserve aux Services operators.

OPER_HELP_SET
	Syntaxe: SET option valeur
	
	Contrle diffrentes options globales aux Servies. 
	Les noms des options actuelles sont:
	
	    READONLY   Active ou dsactive le mode lecture-seule.
	    DEBUG      Active ou dsactive le mode de dboguage
	    NOEXPIRE   Active ou dsactive le mode sans expiration
	
	Rserve aux Services admins.

OPER_HELP_SET_READONLY
	Syntaxe: SET READONLY {ON | OFF}
	
	Active ou dsactive le mode lecture-seule. Dans le mode 
	lecture-seule, les utilisateurs normaux ne seront pas 
	autoriss  modifier les donnes des Services, comprenant
	les access lists des channels et nicknames, etc. Les IRCops
	ayant suffisamment de droits sur les Services pourront 
	modifier l'AKILL list des services et effacer ou interdire
	des nicks et channels, mais de tels changements ne seront
	pas sauvegards  moins que le mode lecture-seule ne soit
	dsactiv avant que les Services ne soient arrts ou
	relancs.
	
	Cette option est quivalente  l'option de la ligne de commande
	-readonly.

OPER_HELP_SET_DEBUG
	Syntaxe: SET DEBUG {ON | OFF | nombre}
	
	Active ou dsactive le debug mode. Dans le debug mode, toutes
	les donnes envoyes vers et par les Services ainsi qu'un bon
	nombre d'autres messages de dboguage sont crits dans le 
	fichier de log. Si nombre est donn, le debug mode est activ,
	avec le niveau de dboguage  nombre.
	
	Cette option est quivalente  l'option de la ligne de commande
	-debug.
	
OPER_HELP_SET_NOEXPIRE
	Syntaxe: SET NOEXPIRE {ON | OFF}
	
	Active ou dsactive le mode sans expiration. Dans le mode 
	sans expiration, les nicks, channels, akills et exceptions 
	n'expireront pas jusqu' ce que l'option soit dsactive.
	
	Cette option est quivalente  l'option de la ligne de commande
	-noexpire.

OPER_HELP_JUPE
	Syntaxe: JUPE serveur [raison]
	
	Demande aux Services de jupiter un serveur -- c'est  dire,
	crer un faux serveur connect aux Services ce qui empche
	le vrai serveur ayant ce nom de se connecter. Le jupe peut
	tre enlev en utilisant un SQUIT normal. Si une raison
	est donne, elle est place dans le champ d'information du
	serveur; sinon, l'information du serveur contiendra le 
	texte "Jupitered by <nick>", laissant paratre le nick
	de la personne qui a jupitered le serveur.
	
	Rserve aux Services admins.

OPER_HELP_RAW
	Syntaxe: RAW texte
	
	Envoie une chane de texte directement au serveur sur 
	lequel les Services sont connects. Cette commande a un
	champ d'utilisation trs limit, et peut causer des
	troubles dans un rseau en cas de mauvaise utilisation.
	N'UTILISEZ PAS CETTE COMMANDE  moins d'tre absolument
	sr de ce que vous faites!
	
	Rserve aux Services admins.

OPER_HELP_UPDATE
	Syntaxe: UPDATE
	
	Provoque la mise  jour de toutes les bases de donnes ds
	que vous le demandez.
	
	Rserve aux Services admins.

OPER_HELP_QUIT
	Syntaxe: QUIT
	
	Provoque un arrt immdiat des services; les bases de donnes
	ne sont pas sauvegardes. Cette commande ne devrait pas tre
	utilise  moins que des dommages dans la copie en mmoire des
	bases de donnes ne soient souponns. Pour des arrts normaux,
	utilisez la commande SHUTDOWN.
	
	Rserve aux Services admins.

OPER_HELP_SHUTDOWN
	Syntaxe: SHUTDOWN
	
	Provoque la sauvegarde de toutes les bases de donnes puis
	l'arrt des services.
	
	Rserve aux Services admins.

OPER_HELP_RESTART
	Syntaxe: RESTART
	
	Provoque la sauvegarde de toutes les bases de donnes et
	le redmarrage des Services (c'est  dire qu'il arrte
	le programme et le relance immdiatement).
	
	Rserve aux Services admins.

OPER_HELP_KILLCLONES
	Syntaxe: KILLCLONES nick
	
	Dconnecte tous les utilisateurs qui ont la mme host que
	nick. Une AKILL temporaire, de la forme *@host, est
	ajoute pour empcher les clients de se reconnecter
	immdiatement. Un wallops est galement envoy indiquant
	qui a utilis la commande, quelle host est affecte et
	combien d'utilisateurs ont t dconnects. Elle est
	utile pour supprimer un nombre important de clones du
	rseau.
	
	Rserve aux Services admins.
	
OPER_HELP_CHANLIST
	Syntaxe: CHANLIST [{modle | nickname} [SECRET]]
	
	Liste tous les channels actuellement utiliss sur le rseau IRC, qu'ils
	soient enregistrs ou non.
	
	Si modle est donn, seuls les channels correspondants sont lists. Si
	un nickname est donn, les channels sur lesquels est l'utilisateur ayant
	ce nick seront lists. Si SECRET est spcifi, liste seulement les channels 
	correspondants  modle qui ont le mode +s ou +p.
	
	Rserve aux Services admins.
	
OPER_HELP_USERLIST
	Syntaxe: USERLIST [{modle | channel} [INVISIBLE]]
	
	Liste tous les utilisateurs connects sur le rseau IRC, enregistrs
	ou non.
	
	Si modle est donn (format nick!user@host), seuls les utilisateurs 
	correspondants seront lists. Si channel est donn, seuls les 
	utilisateurs du channel seront lists. Si INVISIBLE est spcifi,
	seuls les utilisateurs avec le mode +i seront lists.
	
	Rserve aux Services admins.
	
###########################################################################
#
# BotServ help messages
#
###########################################################################
	
BOT_HELP
	%S vous permet d'avoir un bot sur votre channel.
	Il a t conu pour les utilisateurs qui ne 
	peuvent hberger ou configurer un bot, ou pour
	tre utilis sur les rseaux qui n'autorisent pas
	un bot d'un utilisateur. Les commandes disponibles
	sont listes ci-dessous; pour les utiliser, tapez
	/msg %S command. Pour plus d'information sur
	une commande spcifique, tapez /msg %S HELP command.
	
	BOTLIST            Liste les bots disponibles
	ASSIGN             Attribue un bot  un channel
	SET                Configure les options du bot
	KICK               Configure les kickers
	BADWORDS           Gre la liste des mots interdits
	
	Autres commandes: ACT INFO SAY UNASSIGN
	
	Le bot joindra un channel ds qu'il y aura au moins
	%d utilisateurs dessus.
	
BOT_HELP_BOTLIST
	Syntaxe: BOTLIST
	
	Liste tous les bots disponibles sur ce rseau.
	
BOT_HELP_ASSIGN
	Syntaxe: ASSIGN chan nick
	
	Attribue le bot dsign par nick au channel chan. Vous
	pouvez ensuite configurer le bot pour qu'il convienne 
	vos besoins.
	
BOT_HELP_UNASSIGN
	Syntaxe: UNASSIGN chan
	
	Retire le bot d'un channel. Si vous utilisez cette commande,
	le bot ne joindra plus le channel. Cependant, la configuration
	du bot est conserve donc vous aurez toujours la possibilit
	de rattribuer un bot plus tard sans avoir  le reconfigurer
	entirement.
	
BOT_HELP_INFO
	Syntax: INFO {chan | nick}
	
	Vous permet de voir les informations %S pour un channel
	ou un bot. Si le paramtre est un channel, vous verrez
	des informations sur le channel tels que les kickers
	actifs. Si le paramtre est un nick, vous verrez des
	informations  propos d'un bot, comme le temps de
	cration ou le nombre de channels auxquels il a t
	attribu.
	
BOT_HELP_SET
	Syntaxe: SET channel option parameters
	
	Configure les options du bot.  option peut tre:
	
	    DONTKICKOPS      Pour protger les ops des kicks du bot
	    DONTKICKVOICES   Pour protger les voices des kicks du bot
	    FANTASY          Active les commandes fantaisistes
	    GREET            Active les messages d'accueil
	    SYMBIOSIS        Permet au bot d'agir comme un vrai bot
	
	Tapez /msg %S HELP SET option pour plus d'infos
	sur une option spcifique.
	
BOT_HELP_SET_DONTKICKOPS
	Syntaxe: SET channel DONTKICKOPS {ON|OFF}
	
	Active ou dsactive la protection des ops sur un 
	channel. Quand elle est active, cette option empche
	le bot de kicker les ops mme s'ils ne sont pas concerns
	par le level NOKICK.
	
BOT_HELP_SET_DONTKICKVOICES
	Syntaxe: SET channel DONTKICKOPS {ON|OFF}
	
	Active ou dsactive la protection des voices sur un 
	channel. Quand elle est active, cette option empche
	le bot de kicker les voices mme s'ils ne sont pas concerns
	par le level NOKICK.
	
BOT_HELP_SET_FANTASY
	Syntax: SET channel FANTASY {ON|OFF}
	
	Active ou dsactive le mode fantaisie sur un
	channel. Quand elle est active, cette option
	permet aux utilisateurs d'utiliser les commandes
	!op, !deop, !voice, !devoice, !kick, !kb
	et !unban sur un channel (trouvez comment les utiliser; 
	essayez avec ou sans nick pour chacune, et avec une raison
	pour certaines?).
	
	Notez que les utilisateurs souhaitant utiliser
	les commandes fantaisistes DOIVENT avoir
	suffisamment d'accs pour les levels FANTASIA
	et un autre level qui dpend de la commande
	(par exemple, pour utiliser !op, un utilisateur
	doit avoir suffisamment d'accs pour le level
	OPDEOP).
	
BOT_HELP_SET_GREET
	Syntaxe: SET channel GREET {ON|OFF}
	
	Active ou dsactive le mode message d'accueil
	sur un channel. Quand elle est active, cette option
	fait afficher au bot le message d'accueil de chaque
	utilisateur qui a un accs suffisant au channel.
	
BOT_HELP_SET_SYMBIOSIS
	Syntax: SET channel SYMBIOSIS {ON|OFF}
	
	Active ou dsactive la symbiose sur un channel.
	Quand elle est active, cette option fait faire
	au bot tout ce qui est normalement effectu
	par %CS sur les channels, tels que les MODEs,
	les KICKs, et mme le message d'entre.
	
BOT_HELP_KICK
	Syntaxe: KICK channel option parameters
	
	Configure les kickers du bot.  option peut etre:
	
	    BOLDS         Dtermine si le bot kicke les
	                     caractres gras
	    BADWORDS      Dtermine si le bot kicke les mots 
	                     interdits
	    CAPS          Dtermine si le bot kicke les majuscules
	    COLORS        Dtermine si le bot kicke les couleurs
	    FLOOD         Dtermine si le bot kicke les utilisateurs
	                     qui floodent
	    REPEAT        Dtermine si le bot kicke les rptitions
	    REVERSES      Dtermine si le bot kicke les reverses
	    UNDERLINES    Dtermine si le bot kicke les caractres
	                     souligns
	
	Tapez /msg %S HELP KICK option pour plus d'informations
	sur une option en particulier.

BOT_HELP_KICK_BOLDS
	Syntaxe: KICK channel BOLDS {ON|OFF} [ttb]

	Active ou dsactive le kicker de caractres gras. Quand
	elle est active, cette option demande au bot
	de kicker les utilisateurs qui utilisent des 
	caractres gras.

	ttb est le nombre de fois qu'un utilisateur peut
	se faire kicker avant d'tre banni. Ne donnez
	pas ttb ou mettez le  0 pour dsactiver le systme
	de ban une fois activ.

BOT_HELP_KICK_COLORS
	Syntaxe: KICK channel COLORS {ON|OFF} [ttb]

	Active ou dsactive le kicker de couleurs. Quand
	elle est active, cette option demande au bot
	de kicker les utilisateurs qui utilisent des 
	couleurs.

	ttb est le nombre de fois qu'un utilisateur peut
	se faire kicker avant d'tre banni. Ne donnez
	pas ttb ou mettez le  0 pour dsactiver le systme
	de ban une fois activ.

BOT_HELP_KICK_REVERSES
	Syntaxe: KICK channel REVERSES {ON|OFF} [ttb]

	Active ou dsactive le kicker de reverses. Quand
	elle est active, cette option demande au bot
	de kicker les utilisateurs qui utilisent des 
	reverses.

	ttb est le nombre de fois qu'un utilisateur peut
	se faire kicker avant d'tre banni. Ne donnez
	pas ttb ou mettez le  0 pour dsactiver le systme
	de ban une fois activ.

BOT_HELP_KICK_UNDERLINES
	Syntaxe: KICK channel UNDERLINES {ON|OFF} [ttb]

	Active ou dsactive le kicker de caractres souligns. 
	Quand elle est active, cette option demande au bot
	de kicker les utilisateurs qui utilisent des 
	caractres souligns.

	ttb est le nombre de fois qu'un utilisateur peut
	se faire kicker avant d'tre banni. Ne donnez
	pas ttb ou mettez le  0 pour dsactiver le systme
	de ban une fois activ.
	
BOT_HELP_KICK_BADWORDS
	Syntaxe: KICK #channel BADWORDS {ON|OFF} [ttb]

	Active ou dsactive le kicker de mots interdits. 
	Quand elle est active, cette option demande au bot
	de kicker les utilisateurs qui disent certains mots 
	sur le channel.

	Vous pouvez dfinir les mots interdits pour votre
	channel en utilisant la commande BADWORDS. Tapez
	/msg %S HELP BADWORDS pour plus d'informations.

	ttb est le nombre de fois qu'un utilisateur peut
	se faire kicker avant d'tre banni. Ne donnez
	pas ttb ou mettez le  0 pour dsactiver le systme
	de ban une fois activ.

BOT_HELP_KICK_CAPS
	Syntaxe: KICK channel CAPS {ON|OFF} [ttb [min [percent]]]

	Active ou dsactive le kicker de majuscules. Quand 
	elle est active, cette option demande au bot
	de kicker les utilisateurs qui parlent en MAJUSCULES
	sur le channel.

	Le bot ne kicke que s'il y a au minimum min majuscules
	et qu'elles constituent au moins percent%% de la
	ligne de texte entire (si ces paramtres ne sont pas
	donns, les valeurs par dfaut 10 caractres et 25%% 
	seront utiliss).

	ttb est le nombre de fois qu'un utilisateur peut
	se faire kicker avant d'tre banni. Ne donnez
	pas ttb ou mettez le  0 pour dsactiver le systme
	de ban une fois activ.

BOT_HELP_KICK_FLOOD
	Syntaxe: KICK channel FLOOD {ON|OFF} [ttb [ln [secs]]]

	Active ou dsactive le kicker de flood. Quand 
	elle est active, cette option demande au bot
	de kicker les utilisateurs qui floodent le channel
	en utilisant au moins ln lignes en secs secondes
	(si ces paramtres ne sont pas donns, les valeurs
	par dfaut sont 6 lignes en 10 secondes).
	
	ttb est le nombre de fois qu'un utilisateur peut
	se faire kicker avant d'tre banni. Ne donnez
	pas ttb ou mettez le  0 pour dsactiver le systme
	de ban une fois activ.

BOT_HELP_KICK_REPEAT
	Syntaxe: KICK #channel REPEAT {ON|OFF} [ttb [num]]

	Active ou dsactive le kicker de rptitions. Quand 
	elle est active, cette option demande au bot
	de kicker les utilisateurs qui se rptent num fois
	(si num n'est pas donn, la valeur par dfaut est 3).

	ttb est le nombre de fois qu'un utilisateur peut
	se faire kicker avant d'tre banni. Ne donnez
	pas ttb ou mettez le  0 pour dsactiver le systme
	de ban une fois activ.
	
BOT_HELP_BADWORDS
	Syntaxe: BADWORDS channel ADD mot [SINGLE | START | END]
	         BADWORDS channel DEL {mot | entry-num | liste}
	         BADWORDS channel LIST [mask | liste]
	         BADWORDS channel CLEAR
	
	Gre la liste des mots interdits d'un channel. La liste
	des mots interdits dtermine quels mots doivent tre kicks
	quand le kicker de mots interdits est activ. Pour plus
	d'information, tapez /msg %S HELP KICK BADWORDS.
	
	La commande BADWORDS ADD ajoute le mot donn  la liste
	de mots interdits. Si SINGLE est donn, un kick ne sera
	effectu que si un utilisateur dit le mot en entier. Si
	START est donn, un kick ne sera effectu que si un
	utilisateur dit un mot qui commande par mot. Si END
	est spcifi, un kick ne sera effectu que si un utilisateur
	dit un mot qui se termine par mot. Si vous ne spcifiez
	rien, un kick sera effectu chaque fois que mot est dit
	par un utilisateur.
	
	La commande BADWORDS DEL supprime le mot donn de la liste
	des mots interdits. Si une liste de numro d'entres est
	donn, ces entres seront supprimes. (Voyez l'exemple pour
	LIST ci-dessous.)
	
	La commande BADWORDS LIST affiche la liste des mots 
	interdits. Si un mask joker est donn, seules les entres
	correspondantes au mask seront affiches. Si une liste
	de numro d'entres est donne, seules ces entres seront
	affiches; par exemple:

	   BADWORDS #channel LIST 2-5,7-9
	      Liste les mots interdits 2  5 et 7  9.
	      
	La commande BADWORDS CLEAR supprime toutes les entres
	de la liste des mots interdits.
	      
BOT_HELP_SAY
	Syntaxe: SAY channel texte
	
	Fait dire au bot le texte donn sur le channel donn.

BOT_HELP_ACT
	Syntaxe: ACT channel texte
	
	Fait faire au bot l'quivalent d'une commande "/me"
	sur le channel donn avec le texte donn.

BOT_SERVADMIN_HELP
	
	La commande suivante est disponible pour les Services admins:
	
	    BOT              Gre la liste des bots du rseau
	    
BOT_SERVADMIN_HELP_BOT
	Syntax: BOT ADD nick user host real
	        BOT CHANGE oldnick newnick [user [host [real]]]
	        BOT DEL nick
	        BOT LIST
	
	Permet aux Services admins de crer, modifier, et
	supprimer les bots que les utilisateurs pourront
	utiliser sur leurs channels.
	
	BOT ADD ajoute un bot avec le nick, username, hostname
	et realname donn. Aucun test d'intgrit ne sont effectus
	pour ces donnes, donc faites trs attention.
	BOT CHANGE permet de changer le nick, username, hostname
	ou realname d'un bot tout en conservant les donnes qui
	lui sont associes.
	BOT DEL supprime le bot donn de la liste des bots.  
	BOT LIST est un alias de BOTLIST qui liste tous
	les bots disponibles sur le rseau.
	
	Note: si vous crez un bot ayant un nick enregistr
	avec NickServ, il sera effac. De plus, si un utilisateur
	utilise le nick du bot lors de sa cration ou modification,
	il sera dconnect.